<?php
/**
 * Main functions file
 * 
 * This file is the WordPress functions.php file, which which contains many 
 * of the functions for set up and operation of the theme
 *
 * @package		Jot WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */

 global $jot_options;
 
/* ---- Set content width --------*/
if(!isset( $content_width )) $content_width = 840;


/* ---- load files ---------------*/ 
require(get_template_directory() . '/includes/kha-customizer.php');
require(get_template_directory() . '/includes/jot-post-functions.php');
require(get_template_directory() . '/includes/jot-custom-functions.php');
if( is_admin() ){
	require(get_template_directory() . '/includes/jot-metabox-functions.php');	
}
require(get_template_directory() . '/widgets/jot-social-widget.php');
require(get_template_directory() . '/widgets/jot-slider-widget.php');
require(get_template_directory() . '/widgets/jot-author-widget.php');
require(get_template_directory() . '/widgets/jot-categories-widget.php');
require(get_template_directory() . '/widgets/jot-recent-posts-widget.php');
require(get_template_directory() . '/includes/media-grabber.php');

/* ========================================================================================================
 *                 Scripts and Styles
 * ======================================================================================================== */
/**
 * Load jQuery Scripts
 * 
 * function to load jquery scripts. Some of the functions are conditionally loaded 
 * so that the user can disable naughty scripts
 * @uses is_admin() @uses wp_enqueue_script @uses get_template_directory_uri()
 * 
 */
if ( !function_exists ('jot_load_js')){
	function jot_load_js() {
		global $jot_options;
		$disable_colorbox = intval( $jot_options[ 'jot_disable_colorbox' ] );
		$disable_fitvidsjs = intval( $jot_options[ 'jot_disable_fitvids' ] );
		
		if(!is_admin()){
			
			if ($disable_fitvidsjs != 1) {
				wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '' );
				wp_enqueue_script( 'fitvids-doc-ready', get_template_directory_uri() . '/js/fitvids-doc-ready.js', array( 'jquery' ), '' );
			}
			
			//SlickNav
			wp_enqueue_script( 'jot-slick-nav', get_template_directory_uri() . '/js/slick-nav/jquery.slicknav.js', array( 'jquery' ), '' );
									
			if ($disable_colorbox != 1) {
				wp_enqueue_script( 'jot-jquery-colorbox', get_template_directory_uri() . '/js/colorbox/jquery.colorbox-min.js', array( 'jquery' ), '' );
				wp_enqueue_script( 'jot-colorbox-doc-ready', get_template_directory_uri() . '/js/colorbox/colorbox_doc_ready.js', array( 'jquery' ), '' );
			}
			
			wp_enqueue_script( 'jot-custom_js', get_template_directory_uri() . '/js/doc-ready-scripts.js', array( 'jquery' ), '' );
			
			wp_enqueue_script( 'jot-jquery-flex-slider', get_template_directory_uri() . '/js/flex-slider/jquery.flexslider.js', array( 'jquery' ), '' );
			wp_enqueue_script( 'jot-flex-doc-ready', get_template_directory_uri() . '/js/flex-slider/flex-doc-ready-scripts.js', array( 'jquery' ), '' );

		}
	}
	add_action('wp_enqueue_scripts', 'jot_load_js');
}

/**
 * Load CSS Styles
 * 
 * function to load css styles. Some of the style sheets are conditionally loaded 
 * so as they are part of jQuery plugins
 * @uses jot_get_options() found in jot-options.php
 * WordPress functions - see codex
 * @uses wp_register_style() @uses wp_enqueue_style @uses get_template_directory_uri()
 * @uses get_template_directory_uri()
 * 
 */
if ( !function_exists ('jot_styles')) {
	function jot_styles() {
		global $jot_options;
		
		if( $jot_options['jot_google_header_font'] != '' ) {
			wp_enqueue_style( 'jot_google_header', esc_url( $jot_options['jot_google_header_font'] ) );
		}
		if( $jot_options['jot_google_body_font'] != '' && $jot_options['jot_google_header_font'] != $jot_options['jot_google_body_font'] ) {
			wp_enqueue_style( 'jot_google_body', esc_url( $jot_options['jot_google_body_font'] ) );
		}

		wp_enqueue_style( 'jot_font_awesome_style',get_template_directory_uri() . '/font-awesome/css/font-awesome.min.css',array() );
		wp_enqueue_style( 'jot-style',get_stylesheet_uri(),array() );
		
		$jot_css = jot_custom_css();
		wp_add_inline_style( 'jot-style', $jot_css );

	}
	add_action('wp_enqueue_scripts', 'jot_styles');
}

/*
********* Set up Menu in Dashboard under Appearance **************
*/
if ( !function_exists ('jot_register_menu')){
	function jot_register_menu() {
		register_nav_menu('main-nav' , __( 'Main Menu' , 'jot' ) );
	}
add_action( 'init', 'jot_register_menu' );
}

/**
 * Theme Support Functions
 * 
 * This function adds all theme support functions on the after_setup_theme hook
 * See the WordPress Codex for each support
 * 
 */
if( !function_exists ('jot_theme_supports')){
	function jot_theme_supports () {
		
		// post formats
		add_theme_support( 'post-formats', array( 'aside', 'audio','chat', 'gallery', 'image', 'link', 'quote', 'status', 'video' ) );
		
		//feeds
		add_theme_support('automatic-feed-links');
		
		//thumbnails
		add_theme_support('post-thumbnails');
		add_image_size('jot_wide',180,120,true);
		set_post_thumbnail_size( 840, 9999 );
		
		//enable translation
		load_theme_textdomain('jot', get_template_directory() . '/languages');
		
		//html5 markup for comment lists, comment forms, search forms and galleries.
		add_theme_support('html5' , array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ));
		
		//let WordPress look after the title tags
		add_theme_support('title-tag');	
		
	}
	add_action('after_setup_theme','jot_theme_supports');
}

/**
 * Register Side bars
 * Thanks to Justin Tadlock for the post on sidebars 
 * @link http://justintadlock.com/archives/2010/11/08/sidebars-in-wordpress
 */

if (!function_exists ( 'jot_register_sidebars' )) {
	function jot_register_sidebars() {
	// Sidebars and footer areas
	register_sidebar(array(
						'id' => 'jot_default_sidebar_top',
						'name'=>__( 'Default Sidebar Top', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_action_social_sidebar',
						'name'=>__( 'Jot Action Bar Social Links', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_default_slider_sidebar',
						'name'=>__( 'Default Slider Sidebar', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);		
	register_sidebar(array(
						'id' => 'jot_default_sidebar_before_content',
						'name'=>__( 'Default Sidebar Before Content', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_default_sidebar_after_content',
						'name'=>__( 'Default Sidebar After Content', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_default_sidebar_footer',
						'name'=>__( 'Default Sidebar Footer', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_default_sidebar_copyright',
						'name'=>__( 'Default Sidebar Copyright', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_page_sidebar_top',
						'name'=>__( 'Page Sidebar Top', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_page_slider_sidebar',
						'name'=>__( 'Page Slider Sidebar', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);		
	register_sidebar(array(
						'id' => 'jot_page_sidebar_before_content',
						'name'=>__( 'Page Sidebar Before Content', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_page_sidebar_after_content',
						'name'=>__( 'Page Sidebar After Content', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_page_sidebar_footer',
						'name'=>__( 'Page Sidebar Footer', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_page_sidebar_copyright',
						'name'=>__( 'Page Sidebar Copyright', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_extra_sidebar_1',
						'name'=>__( 'Extra Sidebar 1', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_extra_sidebar_2',
						'name'=>__( 'Extra Sidebar 2', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_extra_sidebar_3',
						'name'=>__( 'Extra Sidebar 3', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_extra_sidebar_4',
						'name'=>__( 'Extra Sidebar 4', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);				
	
	register_sidebar(array(
						'id' => 'jot_extra_sidebar_5',
						'name'=>__( 'Extra Sidebar 5', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'jot_extra_sidebar_6',
						'name'=>__( 'Extra Sidebar 6', 'jot' ),
						'description' => '',
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	}
	add_action( 'widgets_init', 'jot_register_sidebars' );
}

/* ========================================================================================================
 *              Comments and Pingbacks
 * ======================================================================================================== */
/**
 * Javascript setup for threaded comments
 */
if ( !function_exists ('jot_enqueue_comment_reply_script')){
	function jot_enqueue_comment_reply_script() {
		if (is_singular() && comments_open() && (get_option('thread_comments') == 1)) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'jot_enqueue_comment_reply_script' );
}