<?php
/**
 * Custom functions file
 * 
 * This file contains custom functions for the theme
 * 
 * @package		Jot WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
/**
 * Header Function
 * 
 * jot_header() is the functioned called by header-blog.php and header-page.php.
 * It is used to set up the header for the page.
 * 
 * 
 */
global $jot_options;
 
if( !function_exists( 'jot_header' ) ) {
	function jot_header(){

		$logo = esc_url( get_theme_mod( 'jot_header_image' , ''  ) );
		$showtitle = intval( get_theme_mod( 'jot_display_title' , 1 ) );
		$showtagline = intval( get_theme_mod( 'jot_display_description' , 1 ) );
		
		if( $logo != '' ) { ?>
			<a id="jot-logo" href="<?php echo esc_url(home_url('')); ?>/">
				<img class="jot-logo" src="<?php echo esc_url($logo); ?>" alt="logo" />
			</a>
		<?php } else {
			if( $showtitle == 1 && $showtagline == 1 ){ ?>
				<h1 class="jot-title tagline"><a href="<?php echo esc_url(home_url('/')); ?>" title="<?php bloginfo('name'); ?>"><?php bloginfo('name'); ?></a></h1>
				<span class="jot-tagline title"><?php bloginfo('description'); ?></span><br/><br/>
			<?php } elseif( $showtitle == 1 && $showtagline == 0 ){ ?>
				<h1 class="jot-title notagline"><a href="<?php echo esc_url(home_url('/')); ?>" title="<?php bloginfo('name'); ?>"><?php bloginfo('name'); ?></a></h1>
			<?php } elseif( $showtitle == 0 && $showtagline == 1 ){ ?>
				<span class="jot-tagline notitle"><?php bloginfo('description'); ?></span><br /><br />
			<?php }
		}
	}
}

/**
 * Header Menu Function
 * 
 * This function sets up the menu for the header. The menu can be set up left, right, 
 * or centered with and without a border
 * 
 * WordPress Functions - See the Codex
 * @uses has_nav_menu() @uses wp_nav_menu()
 */
 
if( !function_exists( 'jot_header_menu' ) ) {
	function jot_header_menu() {
		
			if(has_nav_menu('main-nav')){
				wp_nav_menu(
					array(
						'theme_location' => 'main-nav',
						'container_class' => 'main-nav-container-class',
						'container_id' => 'main-nav-container-id',
						'menu_class' => 'main-menu-class',
						'menu_id' => 'main-menu-id',
					)
				);
			}
		}
}

/**
 * Search Form Function
 * 
 * Search form changes to use font icon
 * 
 * @uses get_search_query()
 *  
 */
if( !function_exists( 'jot_search_form' ) ) {
	function jot_search_form( $form ) {
		//removed role="search"
		$form = '<form method="get" id="searchform" class="searchform" action="' . esc_url( home_url( '/' ) ). '" >
		<label class="screen-reader-text" for="s">' .__( 'Search for:','jot' ) . '</label>
		<input type="text" value="' . get_search_query() . '" name="s" id="s" />
		<button type="submit" id="searchsubmit" value="" ><i class="fa fa-search"></i></button>
		</form>';
	
		return $form;
		
	}
	add_filter( 'get_search_form', 'jot_search_form' );
}

/**
 * Archive Header Function
 * 
 * This function checks for the type of archive page that is being presented and then adds 
 * the html for the appropriate header to be used for the archive page.
 * Pages affected: Search Results, Posts by Author, Posts by Category, Posts by Tag, Posts by date
 *  
 */
if( !function_exists( 'jot_archive_header' ) ) {
	function jot_archive_header( ) {
			
		global $jot_options; ?>
		
		<header class="jot-archive-header">
			<div class="jot-archive-header-800">
				
				<?php if( is_search() ) { ?>
					
						<div class="jot-archive-header-wrap">
							<h2><i class="fa fa-search"></i><?php _e('Search Results: ','jot'); echo the_search_query(); ?></h2>
						</div>
					
				<?php } elseif( is_author() ) {
						
						$include_bio = intval( $jot_options[ 'jot_include_author_bio' ] ); 
					
						if( $include_bio == 1 && get_the_author_meta('description') != '' ) { ?>

							<div class="jot-author-header">
								<h2><i class="fa fa-user"></i><?php _e('Posts By: ','jot'); the_author(); ?></h2>
								<span class="bio-wrap">
									<?php if ( get_the_author_meta('description') != '' ) {
										echo get_avatar( get_the_author_meta('user_email') , 70 ) ;
										echo '<p>'.get_the_author_meta('description').'</p>';
									} ?>
								</span>		
							</div>
		
						<?php } else { ?>

							<div class="jot-archive-header-wrap">
								<h2><i class="fa fa-user"></i><?php _e('Posts By: ','jot'); the_author(); ?></h2>
							</div>
							
						<?php } ?>
					
				<?php } elseif( is_category() ) { ?>
					
					<div class="jot-archive-header-wrap">
						<h2><i class="fa fa-bookmark-o"></i><?php _e('Posts for Category : ','jot'); echo single_cat_title(); ?></h2>
					</div>
					
				<?php } elseif( is_tag() ) { ?>
					
					<div class="jot-archive-header-wrap">
						<h2><i class="fa fa-tag"></i><?php _e('Posts for Tag : ','jot'); echo single_cat_title(); ?></h2>
					</div>
					
				<?php } elseif( is_date() ) { ?>
					<div class="jot-archive-header-wrap">
						<h2><i class="fa fa-calendar"></i><?php 
								_e('Posts for : ','jot'); 
								if( is_day() ) {
									the_time('F j, Y');
								} elseif ( is_month() ) {
									echo single_month_title(' ');
								} elseif( is_year() ) {
									echo the_time( 'Y' );
								}
							?>
						</h2>
					</div>
				<?php } ?>
			
			</div>
		</header>
		
	<?php }
}


/* ==============================================================================================
 *                        Filters
 * ============================================================================================== */

/**
 * --------------------HTML Validation Filters ------------------------
 *  
 * the rel tag does not validate it says it does not like the term category
 * Discussion at wordpess.org suggests it is an HTML/W#C issue.Browsers do 
 * not use this attribute in any way. However, search engines can use this 
 * attribute to get more information about a link.
 * 
 * This filter simply searches the content for the rel tag and replaces "category tag"
 *  with "tag"
 * 
 */
if ( !function_exists ('jot_html5_fix_the_category')){//rel tag validation fix
	function jot_html5_fix_the_category($content) { 
		$pattern = '/rel="category tag"/';
		$replacement = 'rel="tag"';
		$content = preg_replace($pattern, $replacement, $content);
		return $content;
	}
	add_filter('the_category','jot_html5_fix_the_category');
}

/**
 * wpautop filter fix 
 *
 * Description: Fix issues when shortcodes are embedded in a block of content that is filtered by wpautop.
 * Author URI: http://www.johannheyne.de
 * 
 */

if ( !function_exists ('jot_shortcode_paragraph_insertion_fix')){//Empty Paragraph Fix
	function jot_shortcode_paragraph_insertion_fix($content) { 
	    $array = array (
	        '<p>[' => '[', 
	        ']</p>' => ']', 
	        ']<br />' => ']',
	        ']<br/>' => ']',
	        '<p></p>' => ''
	    );
	    $content = strtr($content, $array);
	    return $content;
	}
	add_filter('the_content', 'jot_shortcode_paragraph_insertion_fix'); 
}

/**
 * This function provides the additional navigation aids:
 * 
 * breadcrumbs,categories,tags,calendar,recent posts
 * 
 */
if ( !function_exists ('jot_more_nav')){//Empty Paragraph Fix
	function jot_more_nav() {
		
		global $jot_options;
		
		if($jot_options['jot_use_more_navi_strip'] != 1 ) return;
		
		//breadcrumb args
		$breadcrumb_args = array(
	        'container'       => 'nav',
	        'before'          => '',
	        'after'           => '',
	        'show_on_front'   => true,
	        'network'         => false,
	        'show_title'      => true,
	        'show_browse'     => false,
	        'echo'            => true,
	
	        'post_taxonomy' => array(
	            // 'post'  => 'post_tag', // 'post' post type and 'post_tag' taxonomy
	            // 'book'  => 'genre',    // 'book' post type and 'genre' taxonomy
	        ),
	
	        'labels' => array(
	            'browse'              =>__( 'Browse:',                               'jot' ),
	            'aria_label'          => esc_attr_x( 'Breadcrumbs', 'breadcrumbs aria label', 'jot' ),
	            //'home'                =>__( 'Home',                                  'jot' ),
	            'home'				=> '<i class="fa fa-home" style="font-size: 1em;margin:0;padding:0;" title="'.esc_html__( 'Home','jot' ).'"></i>',
	            'error_404'           =>__( '404 Not Found',                         'jot' ),
	            'archives'            =>__( 'Archives',                              'jot' ),
	            // Translators: %s is the search query. The HTML entities are opening and closing curly quotes.
	            'search'              =>__( 'Search results for &#8220;%s&#8221;',   'jot' ),
	            // Translators: %s is the page number.
	            'paged'               =>__( 'Page %s',                               'jot' ),
	            // Translators: Minute archive title. %s is the minute time format.
	            'archive_minute'      =>__( 'Minute %s',                             'jot' ),
	            // Translators: Weekly archive title. %s is the week date format.
	            'archive_week'        =>__( 'Week %s',                               'jot' ),
	
	            // "%s" is replaced with the translated date/time format.
	            'archive_minute_hour' => '%s',
	            'archive_hour'        => '%s',
	            'archive_day'         => '%s',
	            'archive_month'       => '%s',
	            'archive_year'        => '%s',
	        )
		);
		
		$jot_use_more_labels = $jot_options['jot_use_more_navi_labels'];
		
		//set up the strip-right side
		if($jot_options['jot_more_navi_loc'] == 'top left' || $jot_options['jot_more_navi_loc'] == 'below action strip left' ) {
			
			if( $jot_options['jot_use_recent_comments_more_navi'] == true ){ ?>
				<div class="jot-recent-comments-wrap left">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-recent-comments-trigger" title="'.__('Recent Comments','jot').'"><a href="#">'.__( 'Comments' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-recent-comments-trigger" title="'.__('Recent Comments','jot').'"><a href="#"><i class="fa fa-comments"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_recent_posts_more_navi'] == true ){ ?>
				<div class="jot-recent-posts-wrap left">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-recent-posts-trigger" title="'.__('Recent Posts','jot').'"><a href="#">'.__( 'Posts' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-recent-posts-trigger" title="'.__('Recent Posts','jot').'"><a href="#"><i class="fa fa-pencil"></i></a></span>';
					} ?>		
				</div>
			<?php }
			if( $jot_options['jot_use_cal_more_navi'] == true ){ ?>
				<div class="jot-calendar-wrap left">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-calendar-trigger" title="'.__('Calendar','jot').'"><a href="#">'.__( 'Dates' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-calendar-trigger" title="'.__('Calendar','jot').'"><a href="#"><i class="fa fa-calendar"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_cat_more_navi'] == true ){ ?>
				<div class="jot-categories-wrap left">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-cat-trigger" title="'.__('Categories','jot').'"><a href="#">'.__( 'Cats' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-cat-trigger" title="'.__('Categories','jot').'"><a href="#"><i class="fa fa-bookmark"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_tag_more_navi'] == true ){ ?>
				<div class="jot-tags-wrap left">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-tag-trigger" title="'.__('Tags','jot').'"><a href="#">'.__( 'Tags' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-tag-trigger" title="'.__('Tags','jot').'"><a href="#"><i class="fa fa-tags"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_meta_more_navi'] == true ){ ?>
				<div class="jot-meta-wrap left">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-meta-trigger" title="'.__('Login','jot').'"><a href="#">'.__( 'Log In' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-meta-trigger" title="'.__('Login','jot').'"><a href="#"><i class="fa fa-lock"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_breadcrumbs'] == true ){ ?>
	 			<div class="jot-breadcrumbs-wrap left">
					<?php //jot_custom_breadcrumbs(); ?>
					<?php if ( function_exists( 'breadcrumb_trail' ) ) breadcrumb_trail($breadcrumb_args); ?>
				</div>
			<?php }
			//call the more navi function
			if( $jot_options['jot_use_meta_more_navi'] == true ){ ?>
				<div class="jot-meta-nav left">
					<?php jot_display_meta(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_cat_more_navi'] == true ){ ?>
				<div class="jot-cat-nav left">
					<?php jot_display_categories(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_tag_more_navi'] == true ){ ?>
				<div class="jot-tag-nav left">
					<?php jot_display_tags(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_cal_more_navi'] == true ){ ?>
				<div class="jot-calendar-nav left">
					<?php get_calendar(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_recent_posts_more_navi'] == true ){ ?>
				<div class="jot-recent-posts-nav left">
					<?php jot_display_recent_posts(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_recent_comments_more_navi'] == true ){ ?>
				<div class="jot-recent-comments-nav left">
					<?php jot_display_recent_comments(); ?>
				</div>
			<?php }
			
		} else {
			if( $jot_options['jot_use_breadcrumbs'] == true ){ ?>
	 			<div class="jot-breadcrumbs-wrap right">
					<?php //jot_custom_breadcrumbs(); ?>
					<?php if ( function_exists( 'breadcrumb_trail' ) ) breadcrumb_trail($breadcrumb_args); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_meta_more_navi'] == true ){ ?>
				<div class="jot-meta-wrap right">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-meta-trigger" title="'.__('Login','jot').'"><a href="#">'.__( 'Log In' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-meta-trigger" title="'.__('Login','jot').'"><a href="#"><i class="fa fa-lock"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_cat_more_navi'] == true ){ ?>
				<div class="jot-categories-wrap right">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-cat-trigger" title="'.__('Categories','jot').'"><a href="#">'.__( 'Cats' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-cat-trigger" title="'.__('Categories','jot').'"><a href="#"><i class="fa fa-bookmark"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_tag_more_navi'] == true ){ ?>
				<div class="jot-tags-wrap right">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-tag-trigger" title="'.__('Tags','jot').'"><a href="#">'.__( 'Tags' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-tag-trigger" title="'.__('Tags','jot').'"><a href="#"><i class="fa fa-tags"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_cal_more_navi'] == true ){ ?>
				<div class="jot-calendar-wrap right">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-calendar-trigger" title="'.__('Calendar','jot').'"><a href="#">'.__( 'Dates' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-calendar-trigger" title="'.__('Calendar','jot').'"><a href="#"><i class="fa fa-calendar"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_recent_posts_more_navi'] == true ){ ?>
				<div class="jot-recent-posts-wrap right">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-recent-posts-trigger" title="'.__('Recent Posts','jot').'"><a href="#">'.__( 'Posts' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-recent-posts-trigger" title="'.__('Recent Posts','jot').'"><a href="#"><i class="fa fa-pencil"></i></a></span>';
					} ?>
				</div>
			<?php }
			if( $jot_options['jot_use_recent_comments_more_navi'] == true ){ ?>
				<div class="jot-recent-comments-wrap right">
					<?php if($jot_use_more_labels && $jot_use_more_labels == '1' ) {
						echo '<span class="jot-show-recent-comments-trigger" title="'.__('Recent Comments','jot').'"><a href="#">'.__( 'Comments' , 'jot' ).'</a></span>';
					}else{
						echo '<span class="jot-show-recent-comments-trigger" title="'.__('Recent Comments','jot').'"><a href="#"><i class="fa fa-comments"></i></a></span>';
					} ?>
				</div>
			<?php }
			//load functions
			if( $jot_options['jot_use_meta_more_navi'] == true ){ ?>
				<div class="jot-meta-nav right">
					<?php jot_display_meta(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_cat_more_navi'] == true ){ ?>
				<div class="jot-cat-nav right">
					<?php jot_display_categories(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_tag_more_navi'] == true ){ ?>
				<div class="jot-tag-nav right">
					<?php jot_display_tags(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_cal_more_navi'] == true ){ ?>
				<div class="jot-calendar-nav right">
					<?php get_calendar(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_recent_posts_more_navi'] == true ){ ?>
				<div class="jot-recent-posts-nav right">
					<?php jot_display_recent_posts(); ?>
				</div>
			<?php }
			if( $jot_options['jot_use_recent_comments_more_navi'] == true ){ ?>
				<div class="jot-recent-comments-nav right">
					<?php jot_display_recent_comments(); ?>
				</div>
			<?php }			
			
		}
		
			
	}
}

/**
 * Helper to validate exclude category list
 * 
 * @return $exclude_ids - list of validated category ids to exclude
 */
if ( !function_exists ('jot_exclude_category_validation')){  
	function jot_exclude_category_validation() {
		global $jot_options;
		$exclude_input = sanitize_text_field( $jot_options[ 'jot_exclude_categories' ] );
		$id_picks = array();
		$id_picks = explode( ',', $exclude_input );
		$counter = 0;
		$filtered_list = '';
		foreach( $id_picks as $pick ) {
			if( intval( $id_picks[$counter] ) >= 1 ) {
				$filtered_list .= intval( $id_picks[$counter] ).',';
			}
			$counter++;
		}
		$exclude_ids = trim( $filtered_list , ',');
		
		return $exclude_ids;
		
	}
}

/**
 * Extract embed from selected content
 * 
 * Modified from wp_extract_urls() in /wp-includes/functions.php
 * 
 * Add content between <q></q>. The function extracts 
 * the content between these tags and then and returns it as a string
 *
 */
if( !function_exists ( 'jot_extract_embed' ) ) {
	function jot_extract_embed( $content ) {
		//$embed_string = array();
		$pattern = "/\<q\>(.*?)\<\/q\>/s";
		preg_match($pattern, $content, $embed_string);
		if( $embed_string ) {
			if( $embed_string[0] ) $embed_string[0] = str_replace('<q>','',$embed_string[0]);
			if( $embed_string[0]) $embed_string[0] = str_replace('</q>','',$embed_string[0]);
			return $embed_string[0];
		}
	}
}

/**
 * Remove content from first [gallery ] tags and return it for display
 */
if( !function_exists ( 'jot_strip_first_gallery' ) ) {
	function jot_strip_first_gallery( $content ) {
		$pattern = "/\[gallery(.*?)\]/s";
		preg_match($pattern, $content, $text_to_search);
		if( isset( $text_to_search[0] ) ) {
			$content = str_replace($text_to_search[0],'',$content);
		}
		$content = str_replace('<p></p>','',$content);
		return $content;
	}
}

/**
 * Remove content from first <q></q> tags and return it for display
 */
if( !function_exists ( 'jot_strip_extracted_quote' ) ) {
	function jot_strip_extracted_quote( $content ) {
		$pattern = "/\<q\>(.*?)\<\/q\>/s";
		preg_match($pattern, $content, $text_to_search);
		if( isset( $text_to_search[0] ) ) {
			$content = str_replace($text_to_search[0],'',$content);
		}
		$content = str_replace('<p></p>','',$content);
		return $content;
	}
}

/*
 * Display Categories
 * 
 */
if( !function_exists ( 'jot_display_categories' ) ) {
	function jot_display_categories() {
		$exclude_list = jot_exclude_category_validation();
		$args = array(
			'exclude'		=> $exclude_list,
			'hierarchical' 	=> 0
		); ?>
		<ul>
			<?php wp_list_categories($args); ?>
		</ul>
	<?php }
}

/*
 * Display Tags
 * 
 */
if( !function_exists ( 'jot_display_tags' ) ) {
	function jot_display_tags() {
		echo '<span>'.__('Tags','jot').'</span>';
		$args = array(
			'smallest'	=> 10,
			'largest' 	=> 10
		);
		wp_tag_cloud( $args );
	}
}

/*
 * Display Recent Posts
 * 
 */
if( !function_exists ( 'jot_display_recent_posts' ) ) {
	function jot_display_recent_posts() {
		$exclude_categories_list = jot_exclude_category_validation();
		$exclude_ids = array();
		$exclude_ids = explode( ',', $exclude_categories_list );
		$args = array(
				'numberposts'=>5,
				'post_status' => 'publish',
				'category__not_in' => $exclude_ids,
				'meta_query' => array(
					array(
						'key' => 'jot_metabox_exclude_post',
						'compare' => 'NOT EXISTS'
						)
					),
				);
		$recent_posts = wp_get_recent_posts( $args );
		echo '<span>'.__('Recent Posts','jot').'</span>';
		echo '<ul>';
			foreach( $recent_posts as $recent ){
				echo '<li><a href="' . get_permalink($recent["ID"]) . '">' .   $recent["post_title"].'</a> </li> ';
			}
		echo '</ul>';
	}
}

/*
 * Display Recent Comments
 * 
 */
if( !function_exists ( 'jot_display_recent_comments' ) ) {
	function jot_display_recent_comments() {
		the_widget( 'WP_Widget_Recent_Comments');
	}
}

/*
 * Display Meta Widget
 * 
 */
if( !function_exists ( 'jot_display_meta' ) ) {
	function jot_display_meta() {
		the_widget( 'WP_Widget_Meta');
	}
}