<?php
/**
 * Custom functions file for adding Jot metabox's to page and post panels
 * 
 * This file contains custom functions for the theme
 * 
 * @package		Jot WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
?>
<?php
/**
 * This file set up as per 
 * @link http://wp.tutsplus.com/tutorials/reusable-custom-meta-boxes-part-1-intro-and-basic-fields/
 * The intent is to set up a generalized set of functions to add options to page set ups, allowing 
 * for custom page options.
 * 
 */
/**
 * =============================================================================================
 *                     Custom Page Meta Box
 * =============================================================================================
 */ 
 /** 
  * Add the Meta Box
  * 
  * source: @link http://codex.wordpress.org/Function_Reference/add_meta_box
  * add_meta_box( $id, $title, $callback, $post_type, $context, $priority, $callback_args );
  * $id : (string) (required) HTML 'id' attribute of the edit screen section Default: None 
  * $title : (string) (required) Title of the edit screen section, visible to user Default: None 
  * $callback : (callback) (required) Function that prints out the HTML for the edit screen section. 
  *             Pass function name as a string
  * $post_type : (string) (required) The type of Write screen on which to show the edit screen section 
  *              ('post', 'page', 'link', or 'custom_post_type' where custom_post_type is the custom post type slug)
  *              Default: None 
  * $context : (string) (optional) The part of the page where the edit screen section should be shown 
  *            ('normal', 'advanced', or 'side'). (Note that 'side' doesn't exist before 2.7)Default: 'advanced' 
  * $priority : (string) (optional) The priority within the context where the boxes should show 
  *             ('high', 'core', 'default' or 'low') Default: 'default' 
  * $callback_args : (array) (optional) Arguments to pass into your callback function. The callback will receive 
  *                  the $post object and whatever parameters are passed through this variable. Default: null 
  * 
  */
if ( !function_exists ('jot_add_page_custom_meta_box') ) {
	function jot_add_page_custom_meta_box() {
		add_meta_box(
			'jot_page_custom_meta_box', // $id  
			'Jot Page Options', // $title  
			'jot_show_page_custom_meta_box', // $callback  
			'page', // $page  
			'normal', // $context  
			'high'); // $priority  
	}
	add_action('add_meta_boxes', 'jot_add_page_custom_meta_box');   
}

/**
 * Array of elements
 * 
 * This section defines the array of elements that will be used to 
 * set up the custom page options
 * 
 */
$jot_page_custom_meta_fields = array(
	array(
		'label'=> __('Page Title Option','jot'),
		'desc'  => __('Select a title layout or no title','jot'),
		'id'    => 'jot_metabox_title',
		'type'  => 'select',
		'options' => array (
			'left'	=>__( 'left', 'jot' ),
			'right'	=>__( 'right', 'jot' ),
			'center'	=>__( 'center', 'jot' ),
			'none'		=>__( 'none', 'jot' ),
		),
		'default' =>'left'
	),
	array(  
		'label'=> __( 'Page Sidebar Top' , 'jot'),
		'desc'  => '',
		'id'    => 'jot_metabox_page_sidebar_top',
		'type'  => 'select',
		'options' => array (
			'jot_no_sidebar'						=> 	__( 'No Sidebar' , 'jot' ),
			'jot_page_sidebar_top'					=>	__( 'Page Sidebar Top' , 'jot' ),
			'jot_page_slider_sidebar'				=>	__( 'Page Slider Sidebar' , 'jot' ),
			'jot_page_sidebar_before_content'		=>	__( 'Page Sidebar Before Content' , 'jot' ),
			'jot_page_sidebar_after_content'		=>	__( 'Page Sidebar After Content' , 'jot' ),
			'jot_page_sidebar_footer'				=>	__( 'Page Sidebar Footer' , 'jot' ),
			'jot_page_sidebar_copyright'			=>	__( 'Page Sidebar Copyright' , 'jot' ),
			'jot_default_sidebar_top'				=>	__( 'Default Sidebar Top' , 'jot' ),
			'jot_default_slider_sidebar'			=>	__( 'Default Slider Sidebar' , 'jot' ),
			'jot_default_sidebar_before_content'	=>	__( 'Default Sidebar Before Content' , 'jot' ),
			'jot_default_sidebar_after_content'		=>	__( 'Default Sidebar After Content' , 'jot' ),
			'jot_default_sidebar_footer'			=>	__( 'Default Sidebar Footer' , 'jot' ),
			'jot_default_sidebar_copyright'			=>	__( 'Default Sidebar Copyright' , 'jot' ),
			'jot_extra_sidebar_1'								=>	__( 'Extra Sidebar 1' , 'jot' ),
			'jot_extra_sidebar_2'								=>	__( 'Extra Sidebar 2' , 'jot' ),
			'jot_extra_sidebar_3'								=>	__( 'Extra Sidebar 3' , 'jot' ),
			'jot_extra_sidebar_4'								=>	__( 'Extra Sidebar 4' , 'jot' ),
			'jot_extra_sidebar_5'								=>	__( 'Extra Sidebar 5' , 'jot' ),
			'jot_extra_sidebar_6'								=>	__( 'Extra Sidebar 6' , 'jot' )
		),
		'default' =>__( 'jot_no_sidebar' , 'jot' ),
	),	
	array(  
		'label'=> __('Page Slider Sidebar','jot'),
		'desc'  => '',
		'id'    => 'jot_metabox_page_slider_sidebar',
		'type'  => 'select',
		'options' => array (
			'jot_no_sidebar'						=> 	__( 'No Sidebar' , 'jot' ),
			'jot_page_sidebar_top'					=>	__( 'Page Sidebar Top' , 'jot' ),
			'jot_page_slider_sidebar'				=>	__( 'Page Slider Sidebar' , 'jot' ),
			'jot_page_sidebar_before_content'		=>	__( 'Page Sidebar Before Content' , 'jot' ),
			'jot_page_sidebar_after_content'		=>	__( 'Page Sidebar After Content' , 'jot' ),
			'jot_page_sidebar_footer'				=>	__( 'Page Sidebar Footer' , 'jot' ),
			'jot_page_sidebar_copyright'			=>	__( 'Page Sidebar Copyright' , 'jot' ),
			'jot_default_sidebar_top'				=>	__( 'Default Sidebar Top' , 'jot' ),
			'jot_default_slider_sidebar'			=>	__( 'Default Slider Sidebar' , 'jot' ),
			'jot_default_sidebar_before_content'	=>	__( 'Default Sidebar Before Content' , 'jot' ),
			'jot_default_sidebar_after_content'		=>	__( 'Default Sidebar After Content' , 'jot' ),
			'jot_default_sidebar_footer'			=>	__( 'Default Sidebar Footer' , 'jot' ),
			'jot_default_sidebar_copyright'			=>	__( 'Default Sidebar Copyright' , 'jot' ),
			'jot_extra_sidebar_1'								=>	__( 'Extra Sidebar 1' , 'jot' ),
			'jot_extra_sidebar_2'								=>	__( 'Extra Sidebar 2' , 'jot' ),
			'jot_extra_sidebar_3'								=>	__( 'Extra Sidebar 3' , 'jot' ),
			'jot_extra_sidebar_4'								=>	__( 'Extra Sidebar 4' , 'jot' ),
			'jot_extra_sidebar_5'								=>	__( 'Extra Sidebar 5' , 'jot' ),
			'jot_extra_sidebar_6'								=>	__( 'Extra Sidebar 6' , 'jot' )
		),
		'default' =>__( 'jot_no_sidebar' , 'jot' ),
	),
	array(  
		'label'=> __('Page Sidebar Before Content','jot'),
		'desc'  => '',
		'id'    => 'jot_metabox_page_sidebar_before_content',
		'type'  => 'select',
		'options' => array (
			'jot_no_sidebar'						=> 	__( 'No Sidebar' , 'jot' ),
			'jot_page_sidebar_top'					=>	__( 'Page Sidebar Top' , 'jot' ),
			'jot_page_slider_sidebar'				=>	__( 'Page Slider Sidebar' , 'jot' ),
			'jot_page_sidebar_before_content'		=>	__( 'Page Sidebar Before Content' , 'jot' ),
			'jot_page_sidebar_after_content'		=>	__( 'Page Sidebar After Content' , 'jot' ),
			'jot_page_sidebar_footer'				=>	__( 'Page Sidebar Footer' , 'jot' ),
			'jot_page_sidebar_copyright'			=>	__( 'Page Sidebar Copyright' , 'jot' ),
			'jot_default_sidebar_top'				=>	__( 'Default Sidebar Top' , 'jot' ),
			'jot_default_slider_sidebar'			=>	__( 'Default Slider Sidebar' , 'jot' ),
			'jot_default_sidebar_before_content'	=>	__( 'Default Sidebar Before Content' , 'jot' ),
			'jot_default_sidebar_after_content'		=>	__( 'Default Sidebar After Content' , 'jot' ),
			'jot_default_sidebar_footer'			=>	__( 'Default Sidebar Footer' , 'jot' ),
			'jot_default_sidebar_copyright'			=>	__( 'Default Sidebar Copyright' , 'jot' ),
			'jot_extra_sidebar_1'								=>	__( 'Extra Sidebar 1' , 'jot' ),
			'jot_extra_sidebar_2'								=>	__( 'Extra Sidebar 2' , 'jot' ),
			'jot_extra_sidebar_3'								=>	__( 'Extra Sidebar 3' , 'jot' ),
			'jot_extra_sidebar_4'								=>	__( 'Extra Sidebar 4' , 'jot' ),
			'jot_extra_sidebar_5'								=>	__( 'Extra Sidebar 5' , 'jot' ),
			'jot_extra_sidebar_6'								=>	__( 'Extra Sidebar 6' , 'jot' )
		),
		'default' =>__( 'jot_no_sidebar' , 'jot' ),
	),
	array(  
		'label'=> __('Page Sidebar After Content','jot'),
		'desc'  => '',
		'id'    => 'jot_metabox_page_sidebar_after_content',
		'type'  => 'select',
		'options' => array (
			'jot_no_sidebar'						=> 	__( 'No Sidebar' , 'jot' ),
			'jot_page_sidebar_top'					=>	__( 'Page Sidebar Top' , 'jot' ),
			'jot_page_slider_sidebar'				=>	__( 'Page Slider Sidebar' , 'jot' ),
			'jot_page_sidebar_before_content'		=>	__( 'Page Sidebar Before Content' , 'jot' ),
			'jot_page_sidebar_after_content'		=>	__( 'Page Sidebar After Content' , 'jot' ),
			'jot_page_sidebar_footer'				=>	__( 'Page Sidebar Footer' , 'jot' ),
			'jot_page_sidebar_copyright'			=>	__( 'Page Sidebar Copyright' , 'jot' ),
			'jot_default_sidebar_top'				=>	__( 'Default Sidebar Top' , 'jot' ),
			'jot_default_slider_sidebar'			=>	__( 'Default Slider Sidebar' , 'jot' ),
			'jot_default_sidebar_before_content'	=>	__( 'Default Sidebar Before Content' , 'jot' ),
			'jot_default_sidebar_after_content'		=>	__( 'Default Sidebar After Content' , 'jot' ),
			'jot_default_sidebar_footer'			=>	__( 'Default Sidebar Footer' , 'jot' ),
			'jot_default_sidebar_copyright'			=>	__( 'Default Sidebar Copyright' , 'jot' ),
			'jot_extra_sidebar_1'								=>	__( 'Extra Sidebar 1' , 'jot' ),
			'jot_extra_sidebar_2'								=>	__( 'Extra Sidebar 2' , 'jot' ),
			'jot_extra_sidebar_3'								=>	__( 'Extra Sidebar 3' , 'jot' ),
			'jot_extra_sidebar_4'								=>	__( 'Extra Sidebar 4' , 'jot' ),
			'jot_extra_sidebar_5'								=>	__( 'Extra Sidebar 5' , 'jot' ),
			'jot_extra_sidebar_6'								=>	__( 'Extra Sidebar 6' , 'jot' )
		),
		'default' =>__( 'jot_no_sidebar' , 'jot' ),
	),
	array(  
		'label'=> __('Page Sidebar Footer','jot'),
		'desc'  => '',
		'id'    => 'jot_metabox_page_sidebar_footer',
		'type'  => 'select',
		'options' => array (
			'jot_page_sidebar_footer'				=>	__( 'Page Sidebar Footer' , 'jot' ),
			'jot_no_sidebar'						=> 	__( 'No Sidebar' , 'jot' ),
			'jot_page_sidebar_top'					=>	__( 'Page Sidebar Top' , 'jot' ),
			'jot_page_slider_sidebar'				=>	__( 'Page Slider Sidebar' , 'jot' ),
			'jot_page_sidebar_before_content'		=>	__( 'Page Sidebar Before Content' , 'jot' ),
			'jot_page_sidebar_after_content'		=>	__( 'Page Sidebar After Content' , 'jot' ),
			'jot_page_sidebar_copyright'			=>	__( 'Page Sidebar Copyright' , 'jot' ),
			'jot_default_sidebar_top'				=>	__( 'Default Sidebar Top' , 'jot' ),
			'jot_default_slider_sidebar'			=>	__( 'Default Slider Sidebar' , 'jot' ),
			'jot_default_sidebar_before_content'	=>	__( 'Default Sidebar Before Content' , 'jot' ),
			'jot_default_sidebar_after_content'		=>	__( 'Default Sidebar After Content' , 'jot' ),
			'jot_default_sidebar_footer'			=>	__( 'Default Sidebar Footer' , 'jot' ),
			'jot_default_sidebar_copyright'			=>	__( 'Default Sidebar Copyright' , 'jot' ),
			'jot_extra_sidebar_1'								=>	__( 'Extra Sidebar 1' , 'jot' ),
			'jot_extra_sidebar_2'								=>	__( 'Extra Sidebar 2' , 'jot' ),
			'jot_extra_sidebar_3'								=>	__( 'Extra Sidebar 3' , 'jot' ),
			'jot_extra_sidebar_4'								=>	__( 'Extra Sidebar 4' , 'jot' ),
			'jot_extra_sidebar_5'								=>	__( 'Extra Sidebar 5' , 'jot' ),
			'jot_extra_sidebar_6'								=>	__( 'Extra Sidebar 6' , 'jot' )
		),
		'default' =>__( 'jot_page_sidebar_footer' , 'jot' ),
	),
	array(  
		'label'=> __('Page Sidebar Copyright','jot'),
		'desc'  => '',
		'id'    => 'jot_metabox_page_sidebar_copyright',
		'type'  => 'select',
		'options' => array (
			'jot_page_sidebar_copyright'			=>	__( 'Page Sidebar Copyright' , 'jot' ),
			'jot_no_sidebar'						=> 	__( 'No Sidebar' , 'jot' ),
			'jot_page_sidebar_top'					=>	__( 'Page Sidebar Top' , 'jot' ),
			'jot_page_slider_sidebar'				=>	__( 'Page Slider Sidebar' , 'jot' ),
			'jot_page_sidebar_before_content'		=>	__( 'Page Sidebar Before Content' , 'jot' ),
			'jot_page_sidebar_after_content'		=>	__( 'Page Sidebar After Content' , 'jot' ),
			'jot_page_sidebar_footer'				=>	__( 'Page Sidebar Footer' , 'jot' ),
			'jot_default_sidebar_top'				=>	__( 'Default Sidebar Top' , 'jot' ),
			'jot_default_slider_sidebar'			=>	__( 'Default Slider Sidebar' , 'jot' ),
			'jot_default_sidebar_before_content'	=>	__( 'Default Sidebar Before Content' , 'jot' ),
			'jot_default_sidebar_after_content'		=>	__( 'Default Sidebar After Content' , 'jot' ),
			'jot_default_sidebar_footer'			=>	__( 'Default Sidebar Footer' , 'jot' ),
			'jot_default_sidebar_copyright'			=>	__( 'Default Sidebar Copyright' , 'jot' ),
			'jot_extra_sidebar_1'								=>	__( 'Extra Sidebar 1' , 'jot' ),
			'jot_extra_sidebar_2'								=>	__( 'Extra Sidebar 2' , 'jot' ),
			'jot_extra_sidebar_3'								=>	__( 'Extra Sidebar 3' , 'jot' ),
			'jot_extra_sidebar_4'								=>	__( 'Extra Sidebar 4' , 'jot' ),
			'jot_extra_sidebar_5'								=>	__( 'Extra Sidebar 5' , 'jot' ),
			'jot_extra_sidebar_6'								=>	__( 'Extra Sidebar 6' , 'jot' )
		),
		'default' =>__( 'jot_page_sidebar_copyright' , 'jot' ),
	),
	
);

/**
 * The Callback
 * 
 * The callback is used to display the options on the page
 * 
 */
if ( !function_exists ('jot_show_page_custom_meta_box') ) {
	function jot_show_page_custom_meta_box() {
		global $jot_page_custom_meta_fields, $post;
		// Use nonce for verification  
		echo '<input type="hidden" name="jot_page_meta_box_nonce" value="'.wp_create_nonce(basename(__FILE__)).'" />';  
		// Begin the field table and loop  
		echo '<table class="form-table">';
		foreach ($jot_page_custom_meta_fields as $field) {
			// get value of this field if it exists for this post  
			$meta = get_post_meta($post->ID, $field['id'], true);

			// begin a table row with  
			echo '<tr> 
					<th><label for="'.$field['id'].'">'.$field['label'].'</label></th> 
					<td>';  
						switch($field['type']) {
							// text  
							case 'text':
								echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$meta.'" size="30" /> 
										&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;
							// textarea  
							case 'textarea':
								echo '<textarea name="'.$field['id'].'" id="'.$field['id'].'" cols="60" rows="4">'.$meta.'</textarea> 
										&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;	
							// checkbox  
							case 'checkbox':
								echo '<input type="checkbox" name="'.$field['id'].'" id="'.$field['id'].'" ',$meta ? ' checked="checked"' : '','/> 
										&nbsp;<label for="'.$field['id'].'">'.$field['desc'].'</label>';
							break;
							// select  
							case 'select':
								$valid_options = array();
								$valid_options = $field['options'];
								
								echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
								foreach ($field['options'] as $key => $option) {
									echo '<option'.selected( $key == $meta ).' value="'.$option.'">'.$option.'</option>';  
								}
								echo '</select>&nbsp;<span class="description">'.$field['desc'].'</span>';  
							break;
							// tax_select  
							case 'tax_select':
								$categories = get_categories();
							
								echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
								foreach ($categories as $category) {
									echo '<option', $meta == $category->name? ' selected="selected"' : '', ' value="'.$category->name.'">'.$category->name.'</option>'; 
								}
								echo '</select>&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;
						}//end switch  
			echo '</td></tr>';
		}// end foreach  
		echo '</table>';// end table
	}
}

/**
 * Save the data
 * 
 * This functon takes the meta data and saves it to the WordPress Database
 */
if ( !function_exists ('jot_save_page_custom_meta') ) {
	function jot_save_page_custom_meta($post_id) {
		global $jot_page_custom_meta_fields;
		
		// verify nonce  
		if (isset($_POST['jot_page_meta_box_nonce']) == false || 
			check_admin_referer( basename(__FILE__) , 'jot_page_meta_box_nonce' ) == false )
			return $post_id;
		// check autosave  
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;
		// check permissions  
		if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
			if (!current_user_can('edit_page', $post_id))
				return $post_id;
		} elseif (!current_user_can('edit_post', $post_id)) {
			return $post_id;
		}
		// loop through fields and save the data  
		foreach ($jot_page_custom_meta_fields as $field) {
			$old = get_post_meta($post_id, $field['id'], true);
			if ($field['type'] == 'select' )   {
				if(isset($_POST[$field['id']])) {
					$values = array();	
					$values = $field['options'];
					foreach ( $values as $key => $value) {
						if($value == $_POST[$field['id']] ){$new = $key;}
					}
					$new = sanitize_text_field($new);
				} else {
					$new = $field['default'];
				}
			} elseif ($field['type'] == 'tax_select' ) {
				if(isset($_POST[$field['id']])) {
					$new = $_POST[$field['id']];
					$new = sanitize_text_field($new);
				}
			} elseif ($field['type'] == 'checkbox' ) {
				$new = ( ( isset($_POST[$field['id']]) && true == $_POST[$field['id']] ) ? true : $field['default'] );
			}
			if( isset( $new ) ) {
				if( isset( $old ) ){
					if($new == $field['default'] ){
						delete_post_meta($post_id, $field['id'], $old);
					}else{
						update_post_meta($post_id, $field['id'], $new);
					}
				}else{
					update_post_meta($post_id, $field['id'], $new);
				}
			}
		} // end foreach  
	}
	add_action('save_post', 'jot_save_page_custom_meta');
}

/**
 * =============================================================================================
 *                     Custom Portfolio Meta Box
 * =============================================================================================
 */ 
 /** 
  * Add the Meta Box
  * 
  * source: @link http://codex.wordpress.org/Function_Reference/add_meta_box
  * add_meta_box( $id, $title, $callback, $post_type, $context, $priority, $callback_args );
  * $id : (string) (required) HTML 'id' attribute of the edit screen section Default: None 
  * $title : (string) (required) Title of the edit screen section, visible to user Default: None 
  * $callback : (callback) (required) Function that prints out the HTML for the edit screen section. 
  *             Pass function name as a string
  * $post_type : (string) (required) The type of Write screen on which to show the edit screen section 
  *              ('post', 'page', 'link', or 'custom_post_type' where custom_post_type is the custom post type slug)
  *              Default: None 
  * $context : (string) (optional) The part of the page where the edit screen section should be shown 
  *            ('normal', 'advanced', or 'side'). (Note that 'side' doesn't exist before 2.7)Default: 'advanced' 
  * $priority : (string) (optional) The priority within the context where the boxes should show 
  *             ('high', 'core', 'default' or 'low') Default: 'default' 
  * $callback_args : (array) (optional) Arguments to pass into your callback function. The callback will receive 
  *                  the $post object and whatever parameters are passed through this variable. Default: null 
  * 
  */
if ( !function_exists ('jot_add_portfolio_custom_meta_box') ) {
	function jot_add_portfolio_custom_meta_box() {
		add_meta_box(
			'jot_portfolio_custom_meta_box', // $id  
			'Jot Portfolio Template Options', // $title  
			'jot_show_portfolio_custom_meta_box', // $callback  
			'page', // $page  
			'normal', // $context  
			'high'); // $priority  
	}
	add_action('add_meta_boxes', 'jot_add_portfolio_custom_meta_box');   
}

/**
 * Array of elements
 * 
 * This section defines the array of elements that will be used to 
 * set up the custom page options
 * 
 */
$jot_portfolio_custom_meta_fields = array(
	/* Portfolio */	
	array(
		'label' => __('Portfolio Feature Category','jot'),
		'desc' => __('Only for Portfolio Pages','jot'),
		'id'    => 'jot_portfolio_category',
		'type'  => 'tax_select'
	),
	array(  
		'label'=> __('Portfolio Columns','jot'),
		'desc'  => __('Only for Portfolio Pages','jot'),
		'id'    => 'jot_portfolio_columns',
 		'type'  => 'select',
		'options' => array (
			'1 column'		=>	__( '1 column' , 'jot' ),
			'2 columns'		=>	__( '2 columns' , 'jot' ),
			'3 columns'		=>	__( '3 columns' , 'jot' ),
			'4 columns'		=>	__( '4 columns' , 'jot' ),
			'fullwidth'		=>	__( 'Full Width' , 'jot' )
		),
		'default' => '1 column'
	),
	array(  
		'label'=> __('Include Portfolio Post Content Title','jot'),
		'desc'  => __('Click to include the post content title','jot'),
		'id'    => 'jot_metabox_include_post_content_title',
		'type'  => 'checkbox',
		'default' => 0
 	),
	array(  
		'label'=> __('Include Portfolio Post Content','jot'),
		'desc'  => __('Not used for 1 column portfolio pages','jot'),
		'id'    => 'jot_metabox_include_post_content',
		'type'  => 'checkbox',
		'default' => 0
 	),
	array(  
		'label'=> __('Include Portfolio Image Caption','jot'),
		'desc'  => __('Only used for all Portfolio Pages','jot'),
		'id'    => 'jot_metabox_include_image_caption',
		'type'  => 'checkbox',
		'default' => 0
	),
	array(  
		'label'=> __('Include Portfolio Image Description','jot'),
		'desc'  => __('Only used for all Portfolio Pages','jot'),
		'id'    => 'jot_metabox_include_image_description',
		'type'  => 'checkbox',
		'default' => 0
	),	
);

/**
 * The Callback
 * 
 * The callback is used to display the options on the page
 * 
 */
if ( !function_exists ('jot_show_portfolio_custom_meta_box') ) {
	function jot_show_portfolio_custom_meta_box() {
		global $jot_portfolio_custom_meta_fields, $post;
		// Use nonce for verification  
		echo '<input type="hidden" name="jot_portfolio_meta_box_nonce" value="'.wp_create_nonce(basename(__FILE__)).'" />';  
		// Begin the field table and loop  
		echo '<table class="form-table">';
		foreach ($jot_portfolio_custom_meta_fields as $field) {
			// get value of this field if it exists for this post  
			$meta = get_post_meta($post->ID, $field['id'], true);

			// begin a table row with  
			echo '<tr> 
					<th><label for="'.$field['id'].'">'.$field['label'].'</label></th> 
					<td>';  
						switch($field['type']) {
							// text  
							case 'text':
								echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$meta.'" size="30" /> 
										&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;
							// textarea  
							case 'textarea':
								echo '<textarea name="'.$field['id'].'" id="'.$field['id'].'" cols="60" rows="4">'.$meta.'</textarea> 
										&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;	
							// checkbox  
							case 'checkbox':
								echo '<input type="checkbox" name="'.$field['id'].'" id="'.$field['id'].'" ',$meta ? ' checked="checked"' : '','/> 
										&nbsp;<label for="'.$field['id'].'">'.$field['desc'].'</label>';
							break;
							// select  
							case 'select':
								$valid_options = array();
								$valid_options = $field['options'];
								
								echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
								foreach ($field['options'] as $key => $option) {
									echo '<option'.selected( $key == $meta ).' value="'.$option.'">'.$option.'</option>';  
								}
								echo '</select>&nbsp;<span class="description">'.$field['desc'].'</span>';  
							break;
							// tax_select  
							case 'tax_select':
								$categories = get_categories();
							
								echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
								foreach ($categories as $category) {
									echo '<option', $meta == $category->name? ' selected="selected"' : '', ' value="'.$category->name.'">'.$category->name.'</option>'; 
								}
								echo '</select>&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;
						}//end switch  
			echo '</td></tr>';
		}// end foreach  
		echo '</table>';// end table
	}
}

/**
 * Save the data
 * 
 * This functon takes the meta data and saves it to the WordPress Database
 */
if ( !function_exists ('jot_save_portfolio_custom_meta') ) {
	function jot_save_portfolio_custom_meta($post_id) {
		global $jot_portfolio_custom_meta_fields;
		
		// verify nonce  
		if (isset($_POST['jot_portfolio_meta_box_nonce']) == false || 
			check_admin_referer( basename(__FILE__) , 'jot_portfolio_meta_box_nonce' ) == false )
			return $post_id;
		// check autosave  
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;
		// check permissions  
		if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
			if (!current_user_can('edit_page', $post_id))
				return $post_id;
		} elseif (!current_user_can('edit_post', $post_id)) {
			return $post_id;
		}
		// loop through fields and save the data  
		foreach ($jot_portfolio_custom_meta_fields as $field) {
			$old = get_post_meta($post_id, $field['id'], true);
			if ($field['type'] == 'select' )   {
				if(isset($_POST[$field['id']])) {
					$values = array();	
					$values = $field['options'];
					foreach ( $values as $key => $value) {
						if($value == $_POST[$field['id']] ){$new = $key;}
					}
					$new = sanitize_text_field($new);
				} else {
					$new = $field['default'];
				}
			} elseif ($field['type'] == 'tax_select' ) {
				if(isset($_POST[$field['id']])) {
					$new = $_POST[$field['id']];
					$new = sanitize_text_field($new);
				}
			} elseif ($field['type'] == 'checkbox' ) {
				$new = ( ( isset($_POST[$field['id']]) && true == $_POST[$field['id']] ) ? true : $field['default'] );
			}
			if( isset( $new ) ) {
				if( isset( $old ) ){
					if($new == $field['default'] ){
						delete_post_meta($post_id, $field['id'], $old);
					}else{
						update_post_meta($post_id, $field['id'], $new);
					}
				}else{
					update_post_meta($post_id, $field['id'], $new);
				}
			}
		} // end foreach  
	}
	add_action('save_post', 'jot_save_portfolio_custom_meta');
}

/**
 * =============================================================================================
 *                     Custom Post Meta Box
 * =============================================================================================
 */
 if ( !function_exists ('jot_add_post_custom_meta_box') ) {
	function jot_add_post_custom_meta_box() {
		add_meta_box(  
			'jot_post_custom_meta_box', // $id  
			'Jot Post Options', // $title  
			'jot_show_post_custom_meta_box', // $callback  
			'post', // $post  
			'normal', // $context  
			'high'); // $priority  
	}
	add_action('add_meta_boxes', 'jot_add_post_custom_meta_box');   
}

/**
 * Array of elements
 */
$jot_post_custom_meta_fields = array(
	array(  
		'label'=> __('Do not display this post','jot'),
		'desc'  => __('Click to exclude in blog, or other pages','jot'),
		'id'    => 'jot_metabox_exclude_post',
		'type'  => 'checkbox',
		'default' => 0
	),
	array(  
		'label'=> __('Link Feature Image to this post','jot'),
		'desc'  => __('Make sure to add some content','jot'),
		'id'    => 'jot_metabox_link_to_post',
		'type'  => 'checkbox',
		'default' => 0
	),
	array(  
		'label'=> __('Link Feature Image to feature image file','jot'),
		'desc'  => __('Great option if you are using color box','jot'),
		'id'    => 'jot_metabox_link_to_image',
		'type'  => 'checkbox',
		'default' => 0
	),
	array(  
		'label'=> __('Feature Image Custom Link','jot'),
		'desc'  => __('Add custom link','jot'),
		'id'    => 'jot_custom_feature_link',
		'type'  => 'url',
		'default' => ''
	),
);

// The Callback
if ( !function_exists ('jot_show_post_custom_meta_box') ) {
	function jot_show_post_custom_meta_box() {
		global $jot_post_custom_meta_fields, $post;
		// Use nonce for verification  
		echo '<input type="hidden" name="jot_post_meta_box_nonce" value="'.wp_create_nonce(basename(__FILE__)).'" />';
		// Begin the field table and loop  
		echo '<table class="form-table">';
		foreach ($jot_post_custom_meta_fields as $field) {
			// get value of this field if it exists for this post  
			$meta = get_post_meta($post->ID, $field['id'], true);
			// begin a table row with  
			echo '<tr>
				<th><label for="'.$field['id'].'">'.$field['label'].'</label></th>
				<td>';
				switch($field['type']) {
					// text  
					case 'text':
						echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.sanitize_text($meta).'" size="30" />
								<br /><span class="description">'.$field['desc'].'</span>';
					break;
					//url
					case 'url':
						echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.esc_url($meta).'" size="30" />
								<br /><span class="description">'.$field['desc'].'</span>';
					break;
					// textarea  
					case 'textarea':
						echo '<textarea name="'.$field['id'].'" id="'.$field['id'].'" cols="60" rows="4">'.$meta.'</textarea>
								<br /><span class="description">'.$field['desc'].'</span>';
					break;
					// checkbox  
					case 'checkbox':
						echo '<input type="checkbox" name="'.$field['id'].'" id="'.$field['id'].'" ',$meta ? ' checked="checked"' : '','/>
								<label for="'.$field['id'].'">'.$field['desc'].'</label>';
					break;
					// select  
					case 'select':
						$valid_options = array();
						$valid_options = $field['options'];
						echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
						foreach ($field['options'] as $option) {
							//echo '<option', $meta == $option['value'] ? ' selected="selected"' : '', ' value="'.$option['value'].'">'.$option['label'].'</option>'; 
							echo '<option', $meta == $option? ' selected="selected"' : '', ' value="'.$option.'">'.$option.'</option>'; 
						}
						echo '</select><br /><span class="description">'.$field['desc'].'</span>';
					break;
						// tax_select  
					case 'tax_select':
						$categories = get_categories();
						$valid_options = array();
						$valid_options = $field['options'];
						echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
						foreach ($categories as $category) {
							//echo '<option', $meta == $option['value'] ? ' selected="selected"' : '', ' value="'.$option['value'].'">'.$option['label'].'</option>'; 
							echo '<option', $meta == $category->name? ' selected="selected"' : '', ' value="'.$category->name.'">'.$category->name.'</option>'; 
						}
						echo '</select><br /><span class="description">'.$field['desc'].'</span>';
					break;
				}//end switch  
			echo '</td></tr>';  
		} // end foreach  
		echo '</table>'; // end table  
	}
}
 
// Save the Data
if ( !function_exists ('jot_save_post_custom_meta') ) {
	function jot_save_post_custom_meta($post_id) {
		global $jot_post_custom_meta_fields;
		
		// verify nonce  
		if (isset($_POST['jot_post_meta_box_nonce']) == false || 
			check_admin_referer( basename(__FILE__) , 'jot_post_meta_box_nonce' ) == false )
			return $post_id;
		// check autosave  
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;
		// check permissions  
		if (isset($_POST['post_type']) && 'post' == $_POST['post_type']) {
			if (!current_user_can('edit_post', $post_id))
				return $post_id;
		} elseif (!current_user_can('edit_post', $post_id)) {
			return $post_id;  
		}
		// loop through fields and save the data  
		foreach ($jot_post_custom_meta_fields as $field) {  
			$old = get_post_meta($post_id, $field['id'], true);
			if ($field['type'] == 'text' )   {
				if(isset($_POST[$field['id']])) {
					$new = $_POST[$field['id']];
					$new = sanitize_text_field($new);
				} else {
					$new = $field['default'];
				}
			} elseif ($field['type'] == 'url' ) {
				if(isset($_POST[$field['id']])) {
					$new = $_POST[$field['id']];
					$new = esc_url($new);
				} else {
					$new = $field['default'];
				}
			} elseif ($field['type'] == 'checkbox' ) {
				$new = ( ( isset($_POST[$field['id']]) && true == $_POST[$field['id']] ) ? true : $field['default'] );
			}
			if( isset( $new ) ) {
				//wp_die($new);
				if( isset( $old ) ){
					if($new == $field['default'] ){
						delete_post_meta($post_id, $field['id'], $old);
					}else{
						update_post_meta($post_id, $field['id'], $new);
					}
				}else{
					update_post_meta($post_id, $field['id'], $new);
				}
			}
		} // end foreach  
	}
	add_action('save_post', 'jot_save_post_custom_meta');
}

?>