<?php
/**
 * Posts functions file
 * 
 * This file contains functions for posts including meta 
 * 
 * @package		Jot WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */

/**
 * This function checks the post format type and calls the appropriate template
 * @link http://codex.wordpress.org/Post_Formats
 */
if( !function_exists( 'jot_post_format' ) ) {
	 function jot_post_format(){

		if ( has_post_format( 'aside' ) ) {
			get_template_part('/template-parts/post-formats/postformat','aside');
		} elseif ( has_post_format( 'audio' )) {
			get_template_part('/template-parts/post-formats/postformat','audio');
		} elseif ( has_post_format( 'chat' )) {
			get_template_part('/template-parts/post-formats/postformat','chat');
		} elseif ( has_post_format( 'gallery' )) {
			get_template_part('/template-parts/post-formats/postformat','gallery');
		} elseif ( has_post_format( 'image' )) {
			get_template_part('/template-parts/post-formats/postformat','image');
		} elseif ( has_post_format( 'link' )) {
			get_template_part('/template-parts/post-formats/postformat','link');
		} elseif ( has_post_format( 'quote' )) {
			get_template_part('/template-parts/post-formats/postformat','quote');
		} elseif ( has_post_format( 'status' )) {
			get_template_part('/template-parts/post-formats/postformat','status');
		} elseif ( has_post_format( 'video' )) {
			get_template_part('/template-parts/post-formats/postformat','video');
		} else {
			get_template_part('/template-parts/post-formats/postformat','standard');
		}

	}
}

/**
 * This function checks the post format type and calls the appropriate template for the grid posts
 * @link http://codex.wordpress.org/Post_Formats
 */
if( !function_exists( 'jot_grid_post_format' ) ) {
	 function jot_grid_post_format(){

		if ( has_post_format( 'aside' ) ) {
			get_template_part('/template-parts/post-formats/postformat','grid_aside');
		} elseif ( has_post_format( 'audio' )) {
			get_template_part('/template-parts/post-formats/postformat','grid_audio');
		} elseif ( has_post_format( 'chat' )) {
			get_template_part('/template-parts/post-formats/postformat','grid_chat');
		} elseif ( has_post_format( 'gallery' )) {
			get_template_part('/template-parts/post-formats/postformat','grid_gallery');
		} elseif ( has_post_format( 'image' )) {
			get_template_part('/template-parts/post-formats/postformat','grid_image');
		} elseif ( has_post_format( 'link' )) {
			get_template_part('/template-parts/post-formats/postformat','grid_link');
		} elseif ( has_post_format( 'quote' )) {
			get_template_part('/template-parts/post-formats/postformat','grid_quote');
		} elseif ( has_post_format( 'status' )) {
			get_template_part('/template-parts/post-formats/postformat','grid_status');
		} elseif ( has_post_format( 'video' )) {
			get_template_part('/template-parts/post-formats/postformat','grid_video');
		} else {
			get_template_part('/template-parts/post-formats/postformat','grid_standard');
		}

	}
}

/** ========================= Page Title =======================================
 * This function is a helper for the page title
 */
if( !function_exists( 'jot_page_title' ) ) {
	 function jot_page_title(){
	 	global $post; 
	 	$jot_page_title_option = sanitize_text_field( ( get_post_meta($post->ID,'jot_metabox_title',true) == ''? 'left title' : get_post_meta($post->ID,'jot_metabox_title',true) ) );
	 	if( $jot_page_title_option != 'none' ){ ?>
	 	
		 	<header class="page-header">
				<div class="page-header-wrap">
					<h2 class="page-title entry-title <?php echo $jot_page_title_option; ?>">
						<?php the_title(); ?>
					</h2>
				</div>
				<div class="jot-title-line"></div>
			</header>
		
		<?php }

	 }
}

/** ========================= Post Titles =======================================
 * This function is a helper for posts and supplys the post title
 */
if( !function_exists( 'jot_post_title' ) ) {
	 function jot_post_title(){
	 	if( is_single() && get_the_title() != '' ){ ?>
	 		<header class="post-header">
				<div class="post-header-wrap">
					<h2 class="post-title entry-title">
						<?php the_title(); ?>
					</h2>
				</div>
				<div class="jot-title-line"></div>
			</header>
	 	<?php }elseif( get_the_title() != '' ){ ?>
	 		<header class="post-header">
				<div class="post-header-wrap">
					<h2 class="post-title entry-title">
						<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
					</h2>
				</div>
				<div class="jot-title-line"></div>
			</header>
	 	<?php }
	 }
}

/** ========================================================================
 *                       Post Meta
 *  ======================================================================== */

 /** ---------------------- Post Format Icon --------------------------------------
 *  display the post formt icon in the post meta, if allowed
 */ 
if ( !function_exists ( 'jot_post_format_icon' ) ) {
	function jot_post_format_icon($icon , $post_format , $post_format_no_translate , $grid) {
		global $jot_options;
		$show_icons = intval( $jot_options['jot_show_post_format_icons'] );
		if($show_icons == 1 ){ 
			if( $post_format_no_translate == 'aside' || $post_format_no_translate == 'status' || $grid == true){?>
				<span class="jot-post-format">
					<i class="post-icon-standard fa <?php echo $icon; ?>" title="<?php echo $post_format.' '.__( 'Post' , 'jot' ); ?>"></i>
				</span>
			<?php } else { ?>
				<span class="jot-post-format">
					<i class="post-icon-standard fa <?php echo $icon; ?>" title="<?php echo $post_format.' '.__( 'Post' , 'jot' ); ?>"></i>
					&nbsp;<?php echo $post_format; ?>
				</span>
			<?php }
		}
	}
}
 
  
/** ---------------------- Edit Button --------------------------------------
 *  is user is logged in and can edit posts display an edit button
 */ 
if ( !function_exists ( 'jot_post_meta_edit' ) ) {
	function jot_post_meta_edit() {
		$user_exists = (is_user_logged_in() && current_user_can( 'edit_posts') )? true:false;
		if( $user_exists == true ){
			edit_post_link(__('Edit','jot'),'<span class="jot-edit"><i class="fa fa-edit" title="'.__('Edit','jot').'"></i>&nbsp;','</span>');
		}
	}
}

/** ---------------------- No Title Button --------------------------------------
 *  provide a link to single.php if there is no title
 */ 
if ( !function_exists ( 'jot_post_meta_no title' ) ) {
	function jot_post_meta_no_title() {
		$title_exists = ( get_the_title() != '' )? true:false;
		if( get_the_title() == "" ) {
			echo '<span class="jot-no-title">'.
					'<a href="'.get_permalink().'" rel="bookmark" title="'.__('Recent Comments','jot').'" >'.
						'<i class="fa fa-warning">&nbsp;</i>'.
						__('Single Page Link','jot').
					'</a>'.
				'</span>';
		}
	}
}

/** ---------------------- include tags --------------------------------------
 *  list the tags for the post
 */ 
if ( !function_exists ( 'jot_post_meta_tags' ) ) {
	function jot_post_meta_tags() {
		global $jot_options;
		$include_tags = intval( $jot_options[ 'jot_tags_in_blog' ] );
		if( $include_tags == 1 && get_the_tags() != '' ){$tags_exist = true;}else{$tags_exist = false;}
		if( true == $include_tags ) {
			if( has_tag() == true ) { ?><span class="jot-taglist"><i class="fa fa-tags" title="<?php _e('Tags','jot'); ?>"></i>&nbsp;<?php the_tags("") ?></span> <?php }
		}
	}
}

/** ---------------------- link pages --------------------------------------
 *  provide page links if they are used
 */ 
if ( !function_exists ( 'jot_post_meta_pages' ) ) {
	function jot_post_meta_pages() {
		$link_pages_exist = (wp_link_pages('echo=0') != '' )? true:false;
		if( true == $link_pages_exist ) { ?>
			<span class="jot-pagelist">
				<?php 
					$page_text = '<i class="fa fa-copy" title="'.__('Pages','jot').'"></i>&nbsp;'; 
					wp_link_pages('before='.$page_text.':&after='); 
				?>
			</span>
		<?php }
	}
}

/** ---------------------- include timestamp --------------------------------------
 *  list the post date
 */ 
if ( !function_exists ( 'jot_post_meta_timestamp' ) ) {
	function jot_post_meta_timestamp( $post_format , $grid ) {
		global $jot_options;
		$include_timestamp = intval( $jot_options[ 'jot_timestamp_in_blog' ] );
		if( true == $include_timestamp  ) {
			if( $post_format == 'status' ) { ?>
				<span class="jot-timestamp post-date updated"><?php the_time(get_option('date_format')); ?></span>
			<?php } elseif( $grid == 'true') { ?>
				<span class="jot-timestamp post-date updated"><i class="fa fa-clock-o" title="<?php the_time(get_option('date_format')); ?>"></i></span>
			<?php } else { ?>
				<span class="jot-timestamp post-date updated"><i class="fa fa-clock-o" title="<?php _e('Timestamp','jot'); ?>"></i>&nbsp;<?php the_time(get_option('date_format')); ?></span>
			<?php }
			
		} else { ?>
				<span class="screen-reader-text updated"><?php the_time(get_option('date_format')); ?></span>
		<?php }
	}
}

/** ---------------------- include author --------------------------------------
 *  list the post author
 */ 
if ( !function_exists ( 'jot_post_meta_author' ) ) {
	function jot_post_meta_author( $post_format ) {
		global $jot_options;
		$include_author = intval( $jot_options[ 'jot_author_in_blog' ] );
		if( true == $include_author ) {
			if( $post_format == 'status' ) { ?>
				<span class="vcard jot-author author fn"><?php the_author_posts_link(); ?></span>	
			<?php } else { ?>
				<span class="vcard jot-author author fn"><i class="fa fa-user" title="<?php _e('Author','jot'); ?>"></i>&nbsp;<?php the_author_posts_link(); ?></span>	
			<?php }
					
		} else { ?>
			<span class="screen-reader-text vcard author fn"><?php _e('By:','jot'); ?>&nbsp;<?php the_author_posts_link(); ?></span>
		<?php }
	}
}

/** ---------------------- include author --------------------------------------
 *  list the post categories
 */ 
if ( !function_exists ( 'jot_post_meta_category' ) ) {
	function jot_post_meta_category() {
		global $jot_options;
		$include_category = intval( $jot_options[ 'jot_category_in_blog' ] );
		if( true == $include_category ) {
			if( has_category() == true ) { ?>
				<span class="jot-categories"><i class="fa fa-bookmark" title="<?php _e('Categories','jot'); ?>"></i>&nbsp;<?php the_category(', '); ?></span>
			<?php }	
		}
	}
}

/** ---------------------- comments link --------------------------------------
 * This function provides the comments count and link
 */
if ( !function_exists ( 'jot_comments_link' ) ) {
	function jot_comments_link() {
		
		global $post;
		$post_comments = get_comments( array ( 'type' => 'comment', 'post_id' => $post->ID ));
		?>
		<span class="jot-post-comments"><i class="fa fa-comment" title="<?php _e('Comments','jot'); ?>"></i>&nbsp;<a href="<?php comments_link(); ?>"><?php echo count($post_comments); ?></a></span>
		<?php

	}
}

/**
 *  Excerpt Filters WordPress Codex
 */
/**
 * Change the excerpt filtering to allow html
 * @link http://wordpress.stackexchange.com/questions/141125/allow-html-in-excerpt/141136#141136
 */
if ( !function_exists( 'jot_allowed_excerpt_tags' ) ) { 
	function jot_allowed_excerpt_tags() {
		// Add custom tags to this string
		return '<script>,<style>,<br>,<div>,<em>,<i>,<ul>,<ol>,<li>,<a>,
		<p>,<img>,<span>,<video>,<audio>,<source>,<blockquote>,<cite>
		<h1><h2><h3><h4><h5><h6><figure><main><header><footer><figcaption><iframe>'; 
	}
}
 
/**
 * @Author: Boutros AbiChedid
 * @Date:   June 20, 2011
 * @Websites: http://bacsoftwareconsulting.com/ ; http://blueoliveonline.com/
 * @Description: Preserves HTML formating to the automatically generated Excerpt.
 * Also Code modifies the default excerpt_length and excerpt_more filters.
 * @Tested: Up to WordPress version 3.1.3
 * http://bacsoftwareconsulting.com/blog/index.php/wordpress-cat/how-to-preserve-html-tags-in-wordpress-excerpt-without-a-plugin/
 * Modified by 
 * @Author: Kevin Archibald
 */
if ( !function_exists( 'jot_trim_excerpt' ) ) { 
	function jot_trim_excerpt($jot_excerpt) {
		
		global $post,$jot_options;
		//initiate some variables
		$more_requested_1 = false;
		$more_requested_2 = false;
		$number_of_words = 0;
		$raw_excerpt = $jot_excerpt;

		if ( '' == $jot_excerpt ) {$jot_excerpt = get_the_content('');}
			
		// detect if a more link was in the post so the Read More button can be displayed
		if( strpos($post->post_content, '<!--more-->') !== false ){ $more_requested_1 = true; }
		if( strpos($jot_excerpt, 'ka-more-link') !== false ){ $more_requested_2 = true; }
		
		if( $more_requested_2 != true ){
		
			$jot_excerpt = do_shortcode( $jot_excerpt);
			$jot_excerpt = apply_filters('the_content', $jot_excerpt);
			$jot_excerpt = str_replace(']]>', ']]&gt;', $jot_excerpt);
			$jot_excerpt = strip_tags($jot_excerpt, jot_allowed_excerpt_tags()); /*IF you need to allow just certain tags. Delete if all tags are allowed */
	
			//Set the excerpt word count and only break after sentence is complete.
			$excerpt_word_count = intval( $jot_options['jot_excerpt_words'] );
			$excerpt_length = apply_filters('excerpt_length', $excerpt_word_count); 
			$tokens = array();
			$excerptOutput = '';
			$count = 0;
	
			// Divide the string into tokens; HTML tags, or words, followed by any whitespace
			preg_match_all('/(<[^>]+>|[^<>\s]+)\s*/u', $jot_excerpt, $tokens);
	
			foreach ($tokens[0] as $token) { 
	
				if ($count >= $excerpt_word_count && preg_match('/[\,\;\?\.\!]\s*$/uS', $token) && $token != '' ) { 
					// Limit reached, continue until , ; ? . or !occur at the end
					$excerptOutput .= trim($token);
					$number_of_words = $count;
					break;
				}
	
				// Add words to complete sentence
				$count++;
	
				// Append what's left of the token
				$excerptOutput .= $token;
				
			}
	
	        $jot_excerpt = trim(force_balance_tags($excerptOutput));
			
			$excerpt_end = '<a class="ka-read-more" href="'. get_permalink( get_the_ID() ) . '" title="'.__('Read More' , 'jot') .'">' . '<span class="read-more-button"><i class="fa  fa-file-text-o"></i></span></a>';
			
			if( $number_of_words >= $excerpt_word_count || $more_requested_1 == true ){
				$jot_excerpt .= $excerpt_end; /*Add read more in new paragraph */
			}
		}else{
			$jot_excerpt = do_shortcode( $jot_excerpt);
		}
		return apply_filters('jot_wp_trim_excerpt', $jot_excerpt, $raw_excerpt);
	}
	remove_filter('get_the_excerpt', 'wp_trim_excerpt');
	add_filter('get_the_excerpt', 'jot_trim_excerpt');
}

/* 
 * Excerpt Password - WordPress Codex - display password form in protected posts
 */
if ( !function_exists( 'jot_excerpt_password_form' ) ) {  
	function jot_excerpt_password_form( $excerpt ) {
	    if ( post_password_required() )
	        $excerpt = get_the_password_form();
	    return $excerpt;
	}
	add_filter( 'the_excerpt', 'jot_excerpt_password_form' );
}

/**  Get Gallery Images - taken from Twenty Eleven
 * Retrieves the IDs for images in a gallery.
 *
 * @uses get_post_galleries() first, if available. Falls back to shortcode parsing,
 * then as last option uses a get_posts() call.
 *
 * @return array List of image IDs from the post gallery.
 */
if( !function_exists( 'jot_get_gallery_images' ) ) {
	 function jot_get_gallery_images() {
	
		$images = array();
		$pattern = get_shortcode_regex();
		preg_match( "/$pattern/s", get_the_content(), $match );
		$atts = shortcode_parse_atts( $match[3] );
		
		if ( isset( $atts['ids'] ) )
			$images = explode( ',', $atts['ids'] );
		
		if ( !$images ) {
			$images = get_posts( array(
				'fields'         => 'ids',
				'numberposts'    => 999,
				'order'          => 'ASC',
				'orderby'        => 'menu_order',
				'post_mime_type' => 'image',
				'post_parent'    => get_the_ID(),
				'post_type'      => 'attachment',
			) );
		}

		return $images;
	 }
}

/* ======================================================================================
 * Chat Functions
 * ====================================================================================== */

/**
 * This function filters the post content when viewing a post with the "chat" post format.  It formats the 
 * content with structured HTML markup to make it easy for theme developers to style chat posts.  The 
 * advantage of this solution is that it allows for more than two speakers (like most solutions).  You can 
 * have 100s of speakers in your chat post, each with their own, unique classes for styling.
 *
 * @author David Chandra
 * @link http://www.turtlepod.org
 * @author Justin Tadlock
 * @link http://justintadlock.com
 * @copyright Copyright (c) 2012
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * @link http://justintadlock.com/archives/2012/08/21/post-formats-chat
 *
 * @global array $jot_post_format_chat_ids An array of IDs for the chat rows based on the author.
 * @param string $content The content of the post.
 * @return string $chat_output The formatted content of the post.
 */
if( !function_exists( 'jot_chat_content' ) ) {
	function jot_chat_content( $content ) {
		global $jot_post_format_chat_ids;
		
		/* ka added this because of filter error on password protecting post */
		if( post_password_required() )
			return $content;
		
		/* If this is not a 'chat' post, return the content. */
		if ( !has_post_format( 'chat' ) )
			return $content;
	
		/* Set the global variable of speaker IDs to a new, empty array for this chat. */
		$jot_post_format_chat_ids = array();
	
		/* Allow the separator (separator for speaker/text) to be filtered. */
		$separator = apply_filters( 'jot_format_chat_separator', ':' );
	
		/* Open the chat transcript div and give it a unique ID based on the post ID. */
		$chat_output = "\n\t\t\t" . '<div id="chat-transcript-' . esc_attr( get_the_ID() ) . '" class="chat-transcript">';
	
		/* Split the content to get individual chat rows. */
		$chat_rows = preg_split( "/(\r?\n)+|(<br\s*\/?>\s*)+/", $content );
	
		/* Loop through each row and format the output. */
		foreach ( $chat_rows as $chat_row ) {
	
			/* If a speaker is found, create a new chat row with speaker and text. */
			if ( strpos( $chat_row, $separator ) ) {
	
				/* Split the chat row into author/text. */
				$chat_row_split = explode( $separator, trim( $chat_row ), 2 );
	
				/* Get the chat author and strip tags. */
				$chat_author = strip_tags( trim( $chat_row_split[0] ) );
	
				/* Get the chat text. */
				$chat_text = trim( $chat_row_split[1] );
	
				/* Get the chat row ID (based on chat author) to give a specific class to each row for styling. */
				$speaker_id = jot_chat_row_id( $chat_author );
	
				/* Open the chat row. */
				$chat_output .= "\n\t\t\t\t" . '<div class="chat-row ' . sanitize_html_class( "chat-speaker-{$speaker_id}" ) . '">';
	
				/* Add the chat row author. */
				$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-author ' . sanitize_html_class( strtolower( "chat-author-{$chat_author}" ) ) . ' vcard"><cite class="fn">' . apply_filters( 'my_post_format_chat_author', $chat_author, $speaker_id ) . '</cite>' . $separator . '</div>';
	
				/* Add the chat row text. */
				$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-text">' . str_replace( array( "\r", "\n", "\t" ), '', apply_filters( 'my_post_format_chat_text', $chat_text, $chat_author, $speaker_id ) ) . '</div>';
	
				/* Close the chat row. */
				$chat_output .= "\n\t\t\t\t" . '</div><!-- .chat-row -->';
			}
	
			/**
			 * If no author is found, assume this is a separate paragraph of text that belongs to the
			 * previous speaker and label it as such, but let's still create a new row.
			 */
			else {
	
				/* Make sure we have text. */
				if ( !empty( $chat_row ) ) {
	
					/* Open the chat row. */
					$chat_output .= "\n\t\t\t\t" . '<div class="chat-row ' . sanitize_html_class( "chat-speaker-{$speaker_id}" ) . '">';
	
					/* Don't add a chat row author.  The label for the previous row should suffice. */
	
					/* Add the chat row text. */
					$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-text">' . str_replace( array( "\r", "\n", "\t" ), '', apply_filters( 'my_post_format_chat_text', $chat_row, $chat_author, $speaker_id ) ) . '</div>';
	
					/* Close the chat row. */
					$chat_output .= "\n\t\t\t</div><!-- .chat-row -->";
				}
			}
		}
	
		/* Close the chat transcript div. */
		$chat_output .= "\n\t\t\t</div><!-- .chat-transcript -->\n";
	
		/* Return the chat content and apply filters for developers. */
		return apply_filters( 'jot_format_chat_content', $chat_output );
	}

	/* Filter the content of chat posts. */
	add_filter( 'the_content', 'jot_chat_content' );
	
	/* Auto-add paragraphs to the chat text. */
	add_filter( 'jot_format_chat_text', 'wpautop' );
	
}

/**
 * This function returns an ID based on the provided chat author name.  It keeps these IDs in a global 
 * array and makes sure we have a unique set of IDs.  The purpose of this function is to provide an "ID"
 * that will be used in an HTML class for individual chat rows so they can be styled.  So, speaker "John" 
 * will always have the same class each time he speaks.  And, speaker "Mary" will have a different class 
 * from "John" but will have the same class each time she speaks.
 *
 * @author David Chandra
 * @link http://www.turtlepod.org
 * @author Justin Tadlock
 * @link http://justintadlock.com
 * @copyright Copyright (c) 2012
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * @link http://justintadlock.com/archives/2012/08/21/post-formats-chat
 *
 * @global array $jot_post_format_chat_ids An array of IDs for the chat rows based on the author.
 * @param string $chat_author Author of the current chat row.
 * @return int The ID for the chat row based on the author.
 */
if( !function_exists( 'jot_chat_row_id' ) ) {
	function jot_chat_row_id( $chat_author ) {
		global $jot_post_format_chat_ids;
	
		/* Let's sanitize the chat author to avoid craziness and differences like "John" and "john". */
		$chat_author = strtolower( strip_tags( $chat_author ) );
	
		/* Add the chat author to the array. */
		$jot_post_format_chat_ids[] = $chat_author;
	
		/* Make sure the array only holds unique values. */
		$jot_post_format_chat_ids = array_unique( $jot_post_format_chat_ids );
	
		/* Return the array key for the chat author and add "1" to avoid an ID of "0". */
		return absint( array_search( $chat_author, $jot_post_format_chat_ids ) ) + 1;
	}
}

/**
 * https://codex.wordpress.org/Customizing_the_Read_More
 */
add_filter( 'the_content_more_link', 'jot_modify_read_more_link' );
function jot_modify_read_more_link() {
	return '<a class="ka-more-link" title="'.__('Read More','jot').'" href="' . get_permalink() . '"><span class="read-more-button"><i class="fa  fa-file-text-o"></i></span></a>';
}
