/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 * 
 * @package   jot WordPress Theme 
 * @copyright Copyright (C) 2015, Kevin Archibald
 * @license	  http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author	  Kevin Archibald <www.kevinsspace.ca/contact/>
 * jot is distributed under the terms of the GNU GPL
 * 
 * This file adds some LIVE to the Theme Customizer live preview. To leverage
 * this, set your custom settings to 'postMessage' and then add your handling
 * here. Your javascript should grab settings from customizer controls, and 
 * then make any necessary changes to the page using jQuery.
 */
( function( $ ) {
	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.jot-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.jot-tagline' ).text( to );
		} );
	} );
	//background color styles
	wp.customize( 'jot_background_color', function( value ) {
		value.bind( function( newval ) {
			$( 'body' ).css('background-color', newval);
			$( '#main-header-800' ).css('background-color', newval);
			$( '.jot_slider_widget_class .flex-viewport,.jot-slider-800 .widget .flex-viewport,.gallery-post-feature .flex-viewport' ).css('background-color', newval);
			$( '.jot-cat-nav .cat-item' ).css('background-color', newval);
			$( '.jot-tag-nav a' ).css('background-color', newval);
			$( '.jot-calendar-nav #wp-calendar td#today' ).css('background-color', newval);
			$( '.jot-calendar-nav #wp-calendar tbody td a' ).css('color', newval);
			$( '.jot-calendar-nav #wp-calendar thead th' ).css('background-color', newval);
			$( '.jot-recent-posts-nav span' ).css('border-bottom', '2px solid ' + newval);
			$( '.jot-recent-comments-nav h2' ).css('border-bottom', '2px solid ' + newval);
			$( '.more-link' ).css('background-color', newval);
			$( '.comment-reply-link' ).css('color', newval);
			$( '#jot-footer .tagcloud a' ).css('background-color', newval);
			$( '.image-post-feature' ).css('background-color', newval);
			$( '.pingback,.trackback,.comment,p.no-comments' ).css('border-top', '1px solid ' + newval);
		} );
	} );
	//background accent color styles
	wp.customize( 'jot_background_accent_color', function( value ) {
		value.bind( function( newval ) {
			$( '#footer-wrap-800' ).css('background-color', newval);
			$( '.jot-breadcrumbs-wrap' ).css('background-color', newval);
			$( '.jot-meta-wrap' ).css('background-color', newval);
			$( '.jot-meta-nav' ).css('background-color', newval);
			$( '.jot-categories-wrap' ).css('background-color', newval);
			$( '.jot-cat-nav' ).css('background-color', newval);
			$( '.jot-tags-wrap' ).css('background-color', newval);
			$( '.jot-tag-nav' ).css('background-color', newval);
			$( '.jot-calendar-wrap' ).css('background-color', newval);
			$( '.jot-calendar-nav' ).css('background-color', newval);
			$( '.jot-recent-posts-wrap' ).css('background-color', newval);
			$( '.jot-recent-posts-nav' ).css('background-color', newval);
			$( '.jot-recent-comments-wrap' ).css('background-color', newval);
			$( '.jot-recent-comments-nav' ).css('background-color', newval);
			$( '.jot-archive-header-wrap' ).css('background-color', newval);
			$( '.jot-author-header' ).css('background-color', newval);
			$( '.tagcloud a' ).css('background-color', newval);
			$( '.wp-pagenavi a,.wp-pagenavi span.pages' ).css('background-color', newval);
			$( '.wp-pagenavi span.current' ).css('color', newval);
			$( 'article.format-aside.post' ).css('background-color', newval);
			$( '.comment-list .bypostauthor .comment-author:before' ).css('color', newval);
		} );
	} );
	//background text color styles
	wp.customize( 'jot_background_text_color', function( value ) {
		value.bind( function( newval ) {
			$( 'body' ).css('color', newval);
			$( '#main-header-800' ).css('color', newval);
			$( '.jot_slider_widget_class .flex-viewport,.jot-slider-800 .widget .flex-viewport,.gallery-post-feature .flex-viewport' ).css('color', newval);
			$( '.jot-archive-header-wrap' ).css('color', newval);
			$( '.jot-archive-header i' ).css('color', newval);
			$( '.jot-author-header' ).css('color', newval);
			$( '.comment-reply-link' ).css('color', newval);
			$( '.comment-list .bypostauthor .comment-author:before' ).css('color', newval);
			$( '.wp-pagenavi a, .wp-pagenavi span.pages' ).css('color', newval);
			$( '.wp-pagenavi span.current' ).css('background-color', newval);
			$( 'article.format-aside.post' ).css('color', newval);
		} );
	} );
	//background link color styles
	wp.customize( 'jot_background_link_color', function( value ) {
		value.bind( function( newval ) {
			//$( 'body a' ).css('color', newval);
			$( '.jot-more-navigation-800 a' ).css('color', newval);
			$( '.widget a' ).css('color', newval);
			$( '#main-header a' ).css('color', newval);
			$( '#footer-wrap-800 a' ).css('color', newval);
			$( '.jot-calendar-nav #wp-calendar tbody td a' ).css('color', newval);
			$( '#searchform .keyword' ).css('color', newval);
			$( 'article.format-aside .post-content .jot-author a' ).css('color', newval);
			$( '.aside-post-icon span i' ).css('color', newval);
			$( '.postpagenav a' ).css('color', newval);
		} );
	} );
	//action bar
	wp.customize( 'jot_action_bar_background_color', function( value ) {
		value.bind( function( newval ) {
			$( '#action-header-800' ).css('background-color', newval);
		} );
	} );
	//jot action buttons
	wp.customize( 'jot_action_button_background_color', function( value ) {
		value.bind( function( newval ) {
			$( '#jot-mobile-button,.jot-contact,.jot-show-search-trigger,.action-search' ).css('background-color', newval);
			$( '.action-search input' ).css('border','1px solid ' + newval);
		} );
	} );
	wp.customize( 'jot_action_button_icon_color', function( value ) {
		value.bind( function( newval ) {
			$( '#jot-mobile-button a,.jot-contact i,.jot-show-search-trigger i,.action-search i' ).css('color', newval);
		} );
	} );
	//content background color styles
	wp.customize( 'jot_content_color', function( value ) {
		value.bind( function( newval ) {
			$( '#action-header-800' ).css('background-color', newval);
			$( 'article.post' ).css('background-color', newval);
			$( 'article.page' ).css('background-color', newval);
		} );
	} );
	//content text color
	wp.customize( 'jot_content_text_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.post' ).css('color', newval);
			$( 'article.page' ).css('color', newval);
			$( '.post-header-wrap' ).css('border-bottom', '1px solid ' + newval);
			$( '.jot-title-line' ).css('border-bottom', '1px solid ' + newval);
		} );
	} );
	//content link color
	wp.customize( 'jot_content_link_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.post a' ).css('color', newval);
			$( 'article.page a' ).css('color', newval);
		} );
	} );
	//aside post format
	wp.customize( 'jot_aside_background_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-aside.post' ).css('background-color', newval);
		} );
	} );
	wp.customize( 'jot_aside_text_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-aside.post,article.sticky.format-aside .status-sticky:before' ).css('color', newval);
		} );
	} );
	wp.customize( 'jot_aside_link_color', function( value ) {
		value.bind( function( newval ) {
			//$( 'article.format-aside .post-content .jot-author a,.aside-post-icon span i' ).css('color', newval);
			$( 'article.format-aside a,.aside-post-icon span i' ).css('color', newval);
		} );
	} );
	//status post format
	wp.customize( 'jot_status_background_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-status.post' ).css('background-color', newval);
		} );
	} );
	wp.customize( 'jot_status_text_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-status.post' ).css('color', newval);
		} );
	} );
	wp.customize( 'jot_status_link_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-status a,.status-post-icon i' ).css('color', newval);
		} );
	} );
	//quote post format - feature area
	wp.customize( 'jot_quote_background_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-quote .quote-post-feature' ).css('background-color', newval);
		} );
	} );
	wp.customize( 'jot_quote_text_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-quote .quote-post-feature' ).css('color', newval);
		} );
	} );
	wp.customize( 'jot_quote_link_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-quote.post .quote-post-feature .quote-post-feature-author a' ).css('color', newval);
		} );
	} );
	wp.customize( 'jot_quote_icon_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-quote.post .quote-post-feature .quote-post-feature-icon' ).css('color', newval);
		} );
	} );
	//quote post format - content area
	wp.customize( 'jot_quote_content_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-quote .post-content blockquote' ).css('background-color', newval);
		} );
	} );
	wp.customize( 'jot_content_text_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-quote .post-content blockquote' ).css('color', newval);
		} );
	} );
	//audio post format - content area
	wp.customize( 'jot_audio_message_background_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-audio .post-content cite' ).css('background-color', newval);
		} );
	} );
	wp.customize( 'jot_audio_message_text_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-audio .post-content cite' ).css('color', newval);
		} );
	} );
	//chat post format
	wp.customize( 'jot_chat_background_color', function( value ) {
		value.bind( function( newval ) {
			$( 'article.format-chat .post-content' ).css('background-color', newval);
		} );
	} );
	//image post format
	wp.customize( 'jot_image_wrap_background_color', function( value ) {
		value.bind( function( newval ) {
			$( '.post-format-image-wrap' ).css('background-color', newval);
		} );
	} );
	wp.customize( 'jot_image_wrap_text_color', function( value ) {
		value.bind( function( newval ) {
			$( '.post-format-image-wrap' ).css('color', newval);
		} );
	} );
	//quote post format - content area
	wp.customize( 'jot_image_meta_background_color', function( value ) {
		value.bind( function( newval ) {
			$( '.post-format-meta' ).css('background-color', newval);
		} );
	} );
	wp.customize( 'jot_image_meta_text_color', function( value ) {
		value.bind( function( newval ) {
			$( '.post-format-meta' ).css('color', newval);
		} );
	} );
	// font-size
	wp.customize( 'jot_font_size', function( value ) {
		value.bind( function( newval ) {
			$( 'body' ).css('font-size', newval);
		} );
	} );
} )( jQuery );