<?php
/*
Plugin Name: Jot Author Widget
Plugin URI: http://kevinsspace.ca/demo4/
Description: A widget for the Jot Theme that displays a WordPress Author
Version: 1.0.2
Author: Kevin Archibald
Author URI: http://kevinsspace.ca/
License: GPLv3
 */
 
/**
 * Author Widget
 *
 * This file is a widget that will allow you to set up a bio for your authors
 *
 * @package		Jot WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
// use widgets_init action hook to execute custom function
 add_action ( 'widgets_init','jot_author_register_widget' );

//register our widget 
 function jot_author_register_widget() {
 	register_widget ( 'jot_author_widget' );
 }
 
 //widget class
class jot_author_widget extends WP_Widget {

    //process the new widget
    public function __construct() {
        $widget_ops = array( 
			'classname' => 'jot_author_widget_class', 
			'description' => __('Display author biography','jot') 
			); 
        parent::__construct( 'jot_author_widget', __('Jot Author Widget','jot'), $widget_ops );
    }
 	
 	// Form for widget setup
 	public function form ( $instance ) {
 		$jot_author_defaults = array(
 			'jot_author_title' => __('About the Author','jot'),
 			'jot_author_name' => '',
 			'jot_author_email' => '',
 			'jot_author_website' => '',
 			'jot_author_bio' => ''
		);
		
		$instance = wp_parse_args( (array) $instance, $jot_author_defaults );
		$title = $instance['jot_author_title'];
		$name = $instance['jot_author_name'];
		$email = $instance['jot_author_email'];
		$website = $instance['jot_author_website'];
		$bio = $instance['jot_author_bio'];
		
		echo '<p>'.__( 'Title : ' , 'jot' ).
					'<input class="widefat" id="'.esc_attr( $this->get_field_id( 'jot_author_title' ) ).
					'" name="'.esc_attr( $this->get_field_name( 'jot_author_title' ) ).'" type="text" 
					value="'.sanitize_text_field( $title ).'" /></p>';
		echo '<p>'.__( 'Name : ' , 'jot' ).
					'<input class="widefat" id="'.esc_attr( $this->get_field_id( 'jot_author_name' ) ).
					'" name="'.esc_attr( $this->get_field_name( 'jot_author_name' ) ).
					'" type="text" value="'.sanitize_text_field( $name ).'" /></p>';
		echo '<p>'.__( 'Email : ' , 'jot' ).
					'<input class="widefat" id="'.esc_attr( $this->get_field_id( 'jot_author_email' ) ).
					'" name="'.esc_attr( $this->get_field_name( 'jot_author_email' ) ).
					'" type="text" value="'.esc_attr( $email ).'" /></p>';
		echo '<p>'.__( 'Website : ' , 'jot' ).
					'<input class="widefat" id="'.esc_attr( $this->get_field_id( 'jot_author_website' ) ).
					'" name="'.esc_attr( $this->get_field_name( 'jot_author_website' ) ).
					'" type="text" value="'.esc_url( $website ).'" /></p>';
		echo '<p>'.__('Biography : ','jot').'<textarea class="widefat" id="'.esc_attr( $this->get_field_id( 'jot_author_bio' ) ).
					'" name="'.esc_attr( $this->get_field_name( 'jot_author_bio' ) ).'">'.esc_textarea( $bio ).'</textarea></p>';
			
	}
	
	//save the widget settings
	public function update ( $new_instance, $old_instance ) {
		$instance = $old_instance;
        $instance['jot_author_title'] = sanitize_text_field( $new_instance['jot_author_title'] );
		$instance['jot_author_name'] = sanitize_text_field( $new_instance['jot_author_name'] );
		$instance['jot_author_email'] = sanitize_email( $new_instance['jot_author_email'] );
		$instance['jot_author_website'] = esc_url_raw( $new_instance['jot_author_website'] );
		$instance['jot_author_bio'] = sanitize_text_field( $new_instance['jot_author_bio'] );

		return $instance;
	}
	
	//display the widget
	public function widget($args, $instance) {

		extract ( $args);
		echo $before_widget;
		$title = apply_filters( 'widget_title', $instance['jot_author_title'] );
		if ( !empty( $title )) { echo $before_title.$title.$after_title; }
		$jot_author_name = esc_attr( $instance['jot_author_name'] );
		$jot_author_email = esc_attr( $instance['jot_author_email'] );
		$jot_author_website = esc_url( $instance['jot_author_website'] );
		$jot_author_bio = esc_attr( $instance['jot_author_bio'] );

		echo '<div class="jot-author-widget">';

			if( $jot_author_email != '' ) echo '<span class="author-widget-avatar">'.get_avatar( $jot_author_email , 50 ).'</span>';
			if( $jot_author_name != '' ) { echo '<span class="author-widget-name">'.$jot_author_name.'</span><br/>'; }
			if( $jot_author_bio != '' ) {
				echo '<span class="author-widget-bio">'.$jot_author_bio.'</span>';
			} else {
				echo __('You should probably put a few nice words here...it is a bio after all :)','jot');
			}

		if( $jot_author_website != '' ) { echo '<br/><a class="author-widget-website" href="'.esc_url( $jot_author_website ).'" title="'.__('Author Website','jot').'" target="_blank" >Website</a>'; }

		echo '</div>';

		echo $after_widget; 
	}
}		