<?php
/*
Plugin Name: Jot Category Widget
Plugin URI: http://kevinsspace.ca/demo4/
Description: A widget for the Jot Theme that allows the user to display all categories except those selected to exclude in the Jot Options Panel.
Version: 1.0
Author: Kevin Archibald
Author URI: http://kevinsspace.ca/
License: GPLv3
 */
 
/**
 * Jot Category Widget
 *
 * This file is a widget was modified from the WordPress Category Widget
 *
 * @package		Jot WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
/**
 * Categories widget class
 *
 * @since 2.8.0
 */
// use widgets_init action hook to execute custom function
 add_action ( 'widgets_init','jot_register_category_widget' );
 
//register our widget 
function jot_register_category_widget() {
	register_widget ( 'jot_category_widget' );
}
  
class jot_category_widget extends WP_Widget {

	//process the new widget
    public function __construct() {
        $widget_ops = array( 
			'classname' => 'jot_category_widget_class', 
			'description' => __('Display selected categories','jot') 
			); 
        parent::__construct( 'jot_category_widget', __('Jot Category Widget','jot'), $widget_ops );
    }
	
	public function form( $instance ) {
		
		//Defaults
		$jot_category_defaults = array(
 			'jot_title' => __('Categories','jot'),
 			'jot_count' => 0,
 			'jot_hierarchical' => 0,
 			'jot_dropdown' => 0
		);
		
		$instance = wp_parse_args( (array) $instance, $jot_category_defaults );
		
		$title = esc_attr( $instance['jot_title'] );
		$count = $instance['jot_count'];
		$hierarchical = $instance['jot_hierarchical'];
		$dropdown =  $instance['jot_dropdown'];
				
		//validate data
		if( $count != 1 ) $count = 0;
		if( $hierarchical != 1 ) $hierarchical = 0;
		if( $dropdown != 1 ) $dropdown = 0;
				
		?>
		
			<p>
				<label for="<?php echo $this->get_field_id('jot_title'); ?>"><?php _e( 'Title:', 'jot' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id('jot_title'); ?>" name="<?php echo $this->get_field_name('jot_title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
	
			<p>
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('jot_dropdown'); ?>" name="<?php echo $this->get_field_name('jot_dropdown'); ?>"<?php checked( $dropdown ); ?> />
				<label for="<?php echo $this->get_field_id('jot_dropdown'); ?>"><?php _e( 'Display as dropdown', 'jot' ); ?></label><br />
	
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('jot_count'); ?>" name="<?php echo $this->get_field_name('jot_count'); ?>"<?php checked( $count ); ?> />
				<label for="<?php echo $this->get_field_id('jot_count'); ?>"><?php _e( 'Show post counts', 'jot' ); ?></label><br />
	
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('jot_hierarchical'); ?>" name="<?php echo $this->get_field_name('jot_hierarchical'); ?>"<?php checked( $hierarchical ); ?> />
				<label for="<?php echo $this->get_field_id('jot_hierarchical'); ?>"><?php _e( 'Show hierarchy', 'jot' ); ?></label>
			</p>
					
		<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['jot_title'] = strip_tags($new_instance['jot_title']);
		$instance['jot_count'] = !empty($new_instance['jot_count']) ? 1 : 0;
		$instance['jot_hierarchical'] = !empty($new_instance['jot_hierarchical']) ? 1 : 0;
		$instance['jot_dropdown'] = !empty($new_instance['jot_dropdown']) ? 1 : 0;
				
		return $instance;
	}

	public function widget( $args, $instance ) {
		extract( $args );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Categories' , 'jot' ) : $instance['title'], $instance, $this->id_base );

		$c = ! empty( $instance['jot_count'] ) ? '1' : '0';
		$h = ! empty( $instance['jot_hierarchical'] ) ? '1' : '0';
		$d = ! empty( $instance['jot_dropdown'] ) ? '1' : '0';
		$x = jot_exclude_category_validation();

		echo $before_widget;
		if ( $title )
			echo $before_title . $title . $after_title;

		$cat_args = array('orderby' => 'name', 'show_count' => $c, 'hierarchical' => $h, 'exclude' => $x );

		if ( $d ) {
			$cat_args['show_option_none'] = __( 'Select Category' , 'jot' );

			/**
			 * Filter the arguments for the Categories widget drop-down.
			 *
			 * @since 2.8.0
			 *
			 * @see wp_dropdown_categories()
			 *
			 * @param array $cat_args An array of Categories widget drop-down arguments.
			 */
			wp_dropdown_categories( apply_filters( 'widget_categories_dropdown_args', $cat_args ) );
		?>

			<script type='text/javascript'>
			/* <![CDATA[ */
				var dropdown = document.getElementById("cat");
				function onCatChange() {
					if ( dropdown.options[dropdown.selectedIndex].value > 0 ) {
						location.href = "<?php echo home_url(); ?>/?cat="+dropdown.options[dropdown.selectedIndex].value;
					}
				}
				dropdown.onchange = onCatChange;
			/* ]]> */
			</script>

		<?php } else { ?>
			
			<ul>

				<?php
				
					$cat_args['title_li'] = '';

					/**
					 * Filter the arguments for the Categories widget.
					 *
					 * @since 2.8.0
					 *
					 * @param array $cat_args An array of Categories widget options.
					 */
					wp_list_categories( apply_filters( 'widget_categories_args', $cat_args ) );
				?>
				
			</ul>
			
		<?php }

		echo $after_widget;
	}

}
