<?php
/*
Plugin Name: Jot Category Widget
Plugin URI: http://kevinsspace.ca/demo4/
Description: A widget for the Jot Theme that displays recent posts. Posts with categories from the Jot Options panel are excluded. Posts with meta options to exclude are also not included.
Version: 1.0
Author: Kevin Archibald
Author URI: http://kevinsspace.ca/
License: GPLv3
 */
 
/**
 * Jot Recent Posts Widget
 *
 * This file is a widget was modified from the WordPress Category Widget
 * see https://wordpress.org/support/topic/recent-posts-widget-with-category-exclude?replies=12
 *
 * @package		Jot WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
/**
 * Recent_Posts widget w/ category exclude class
 * This allows specific Category IDs to be removed from the Sidebar Recent Posts list
 *
 */
// use widgets_init action hook to execute custom function
 add_action ( 'widgets_init','jot_register_recent_posts_widget' );
 
//register our widget 
function jot_register_recent_posts_widget() {
	register_widget ( 'jot_recent_posts_widget' );
}
class jot_recent_posts_widget extends WP_Widget {

	//process the new widget
    public function __construct() {
        $widget_ops = array( 
			'classname' => 'jot_recent_posts', 
			'description' => __('Display recent posts, allow excluded categories','jot') 
		); 
		parent::__construct( 'jot_recent_posts_widget', __('Jot Recent Posts Widget','jot'), $widget_ops );
    }
	
	public function form( $instance ) {
		
		//Defaults
		$jot_recent_posts_defaults = array(
			'jot_title' => __('Recent Posts','jot'),
			'jot_count' => 5
		);
		
		$instance = wp_parse_args( (array) $instance, $jot_recent_posts_defaults );
		
		$title = esc_attr( $instance['jot_title'] );
		$count = $instance['jot_count'];
			
		//validate data
		$count = is_int( $count ) ? $count : 5;
				
		?>

		<p><label for="<?php echo $this->get_field_id('jot_title'); ?>"><?php _e('Title:','jot'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('jot_title'); ?>" name="<?php echo $this->get_field_name('jot_title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('jot_count'); ?>"><?php _e('Number of posts to show:','jot'); ?></label>
		<input id="<?php echo $this->get_field_id('jot_count'); ?>" name="<?php echo $this->get_field_name('jot_count'); ?>" type="text" value="<?php echo $count; ?>" size="3" /></p>

		<?php
	}
	
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['jot_title'] = strip_tags($new_instance['jot_title']);
		$instance['jot_count'] = !empty($new_instance['jot_count']) ? $new_instance['jot_count'] : 5;
		
		return $instance;
	}

	public function widget( $args, $instance ) {
		global $jot_options;
		
		extract( $args );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Recent Posts' , 'jot' ) : $instance['title'], $instance, $this->id_base );
		
		$c = ! empty( $instance['jot_count'] ) ? $instance['jot_count'] : 5;
		
		$exclude_ids = jot_exclude_category_validation();
		$id_picks = array();
		$id_picks = explode( ',', $exclude_ids );
		$filtered_list = '';
		$counter = 0;
		foreach( $id_picks as $pick ) {
			if( intval( $id_picks[$counter] ) > 1 ) {
				$filtered_list .= '-'.intval( $id_picks[$counter] ).',';
			}
			$counter++;
		}
		$exclude_ids = trim( $filtered_list , ',');
		$x = "'".$exclude_ids."'";
		
		$args = array(
				'numberposts'	=>	$c,
				'post_status'	=> 'publish',
				'category'		=> $x,
				'meta_query'	=> array(
					array(
						'key' => 'jot_metabox_exclude_post',
						'compare' => 'NOT EXISTS'
						)
					),
				);
		
		echo $before_widget;
		if ( $title )
			echo $before_title . $title . $after_title;

		$recent_posts = wp_get_recent_posts( $args );
		
		?>
		<ul>
			<?php 
				foreach( $recent_posts as $recent ){
					echo '<li><a href="' . get_permalink($recent["ID"]) . '">' . $recent["post_title"].'</a> </li> ';
				} 
			?>
		</ul>
			
		<?php

		echo $after_widget;
	}
}