<?php
/*
Plugin Name: Jot Slider Widget
Plugin URI: http://kevinsspace.ca/demo4/
Description: A widget for the Jot theme that sets up and displays a slider of feature images
Version: 1.0
Author: Kevin Archibald
Author URI: http://kevinsspace.ca/
License: GPLv3
* @package		Jot WordPress Theme
* @copyright	Copyright (C) 2015  Kevin Archibald
* @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
* @author		Kevin Archibald <www.kevinsspace.ca/contact/>
*/

// use widgets_init action hook to execute custom function
 add_action ( 'widgets_init','jot_slider_register_widget' );

//register our widget 
 function jot_slider_register_widget() {
 	register_widget ( 'jot_slider_widget' );
 }
 
 //widget class
class jot_slider_widget extends WP_Widget {

    //process the new widget
    public function __construct() {
        $widget_ops = array( 
			'classname' => 'jot_slider_widget_class', 
			'description' => __('Display slider of featured images','jot') 
			); 
        parent::__construct( 'jot_slider_widget', __('Jot Slider Widget','jot'), $widget_ops );
    }
 	
 	// Form for widget setup
 	public function form ( $instance ) {
 		$jot_social_defaults = array(
 			'jot_slider_title' => __('Jot Flex Slider' ,'jot'),
			'jot_slider_type' => 'button nav',
 			'jot_slider_category' => __('feature 1','jot'),
 			'jot_slider_animation' => 'fade',
			'jot_slider_pause' => '6000',
			'jot_slider_transition' => '500',
			'jot_include_post_titles' => 0
		);
		$instance = wp_parse_args( (array) $instance, $jot_social_defaults );
		$title = $instance['jot_slider_title'];
		$slider_type = $instance['jot_slider_type'];
		$slider_category = $instance['jot_slider_category'];
		$slider_animation = $instance['jot_slider_animation'];
		$slider_pause = $instance['jot_slider_pause'];
		$slider_transition = $instance['jot_slider_transition'];
		$include_post_titles = $instance['jot_include_post_titles'];
		?>
			<p><?php _e('Title : ','jot'); ?><input class="widefat" id="<?php echo $this->get_field_id('jot_slider_title'); ?>" name="<?php echo $this->get_field_name('jot_slider_title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
			<p><?php _e('Type : ','jot'); ?>
				<select name="<?php echo $this->get_field_name('jot_slider_type'); ?>">
					<option value="no_nav" <?php selected( $slider_type, "no_nav" ); ?>><?php _e( 'no nav' , 'jot' ); ?></option>
					<option value="button_nav" <?php selected( $slider_type, "button_nav" ); ?>><?php _e( 'button nav' , 'jot' ); ?></option>
					<option value="thumb_nav" <?php selected( $slider_type, "thumb_nav" ); ?>><?php _e( 'thumb nav' , 'jot' ); ?></option>
					<option value="carousel" <?php selected( $slider_type, "carousel" ); ?>><?php _e( 'carousel' , 'jot' ); ?></option>
				</select> 
			</p>
			<p><?php _e('Category : ','jot'); ?>
				<select name="<?php echo $this->get_field_name('jot_slider_category'); ?>">
					<?php 
						$category_list = get_categories();
						foreach($category_list as $category ){
							echo '<option value="'.$category->name.'" '.selected( $slider_category , $category->name ).'>'.$category->name.'</option>';
						}
					?>
				</select>
			</p>
			<p><?php _e('Animation : ','jot'); ?>
				<select name="<?php echo $this->get_field_name('jot_slider_animation'); ?>">
					<option value="fade" <?php selected( $slider_animation, "fade" ); ?>><?php _e( 'fade' , 'jot' ); ?></option>
					<option value="slide" <?php selected( $slider_animation, "slide" ); ?>><?php _e( 'slide' , 'jot' ); ?></option>
				</select> 
			</p>
			<p><?php _e('Slide Pause - milliseconds : ','jot'); ?>
				<select name="<?php echo $this->get_field_name('jot_slider_pause'); ?>">
					<option value="4000" <?php selected( $slider_pause, "4000" ); ?>>4000</option>
					<option value="5000" <?php selected( $slider_pause, "5000" ); ?>>5000</option>
					<option value="6000" <?php selected( $slider_pause, "6000" ); ?>>6000</option>
					<option value="7000" <?php selected( $slider_pause, "7000" ); ?>>7000</option>
					<option value="8000" <?php selected( $slider_pause, "8000" ); ?>>8000</option>
					<option value="9000" <?php selected( $slider_pause, "9000" ); ?>>9000</option>
					<option value="10000" <?php selected( $slider_pause, "10000" ); ?>>10000</option>
					<option value="11000" <?php selected( $slider_pause, "11000" ); ?>>11000</option>
					<option value="12000" <?php selected( $slider_pause, "12000" ); ?>>12000</option>
				</select> 
			</p>
			<p><?php _e('Slide Transition - milliseconds : ','jot'); ?>
				<select name="<?php echo $this->get_field_name('jot_slider_transition'); ?>">
					<option value="500" <?php selected( $slider_transition, "500" ); ?>>500</option>
					<option value="750" <?php selected( $slider_transition, "750" ); ?>>750</option>
					<option value="1000" <?php selected( $slider_transition, "1000" ); ?>>1000</option>
					<option value="1250" <?php selected( $slider_transition, "1250" ); ?>>1250</option>
					<option value="1500" <?php selected( $slider_transition, "1500" ); ?>>1500</option>
					<option value="1750" <?php selected( $slider_transition, "1750" ); ?>>1750</option>
					<option value="2000" <?php selected( $slider_transition, "2000" ); ?>>2000</option>
				</select> 
			</p>
			<p><?php _e('Display Post Titles','jot'); ?> 
				<input name="<?php echo $this->get_field_name('jot_include_post_titles'); ?>" type="checkbox" value="1" <?php if( 1 == $include_post_titles ) echo 'checked="checked"'; ?> />
			</p>
		<?php	
	}
	
	//save the widget settings
	public function update ( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
        $instance['jot_slider_title'] = sanitize_text_field( $new_instance['jot_slider_title'] );
		$instance['jot_slider_type'] = sanitize_text_field( $new_instance['jot_slider_type'] );
		$instance['jot_slider_category'] = sanitize_text_field( $new_instance['jot_slider_category'] );
		$instance['jot_slider_animation'] = sanitize_text_field( $new_instance['jot_slider_animation'] );
		$instance['jot_slider_pause'] = sanitize_text_field( $new_instance['jot_slider_pause'] );
		$instance['jot_slider_transition'] = sanitize_text_field( $new_instance['jot_slider_transition'] );
		isset($new_instance['jot_include_post_titles'])? $instance['jot_include_post_titles'] = strip_tags( $new_instance['jot_include_post_titles'] ):$instance['jot_include_post_titles'] = 0;
		
		return $instance;
	}
	
	//display the widget
	public function widget($args, $instance) {
		global $jot_options;
		extract ( $args);
		isset( $instance['jot_slider_title'] ) ? $title = apply_filters( 'widget_title', $instance['jot_slider_title'] ) : $title = __('Jot Flex Slider','jot');
		isset( $instance['jot_slider_type'] ) ? $slider_type = sanitize_text_field( $instance['jot_slider_type'] ) : $slider_type = 'button_nav';
		isset( $instance['jot_slider_category'] ) ? $slider_category = sanitize_text_field( $instance['jot_slider_category'] ) : $slider_category = __('feature 1','jot');
		isset( $instance['jot_slider_animation'] ) ? $slider_animation = sanitize_text_field( $instance['jot_slider_animation'] ) : $slider_animation = 'fade';
		isset( $instance['jot_slider_pause'] ) ? $slider_pause = sanitize_text_field( $instance['jot_slider_pause'] ) : $slider_pause = '6000';
		isset( $instance['jot_slider_transition'] ) ? $slider_transition = sanitize_text_field( $instance['jot_slider_transition'] ) : $slider_transition = '500';
		isset( $instance['jot_include_post_titles'] ) ? $include_post_titles = intval( $instance['jot_include_post_titles'] ) : $include_post_titles = 0;
		
		echo $before_widget;

		if ( !empty( $title )) { echo $before_title.$title.$after_title;}
		
		if( $slider_type == 'no_nav' ){
			jot_slider_no_nav( $slider_category, $slider_animation, $slider_pause, $slider_transition , $include_post_titles );
		}elseif( $slider_type == 'button_nav' ){
			jot_slider_button_nav( $slider_category, $slider_animation, $slider_pause, $slider_transition , $include_post_titles );
		}elseif( $slider_type == 'thumb_nav' ){
			jot_slider_thumb_nav( $slider_category, $slider_animation, $slider_pause, $slider_transition , $include_post_titles );
		}elseif( $slider_type == 'carousel' ){
			jot_slider_carousel( $slider_category, $slider_animation, $slider_pause, $slider_transition , $include_post_titles );
		}
			
		echo $after_widget; 
	}

}//close the class

/**
 * 
 */
function jot_slider_no_nav( $slider_category, $slider_animation, $slider_pause, $slider_transition , $include_post_titles ) {
	global $jot_feature_category, $post;

	$category_ID = get_cat_ID( $slider_category );		
	$args = array('category'=>$category_ID,'numberposts'=>999);
	$custom_posts = get_posts($args);
	$jot_feature_pic_count = 0;

	if ($category_ID !== 0 && $custom_posts){
		
		echo '<div class="flexslider-wrapper">';
		
			// slider
			echo '<div id="flexslider-feature-no-nav" class="flexslider" data-flex_trans="'.esc_attr( $slider_transition ).'" data-flex_pause="'.esc_attr( $slider_pause ).'" data-flex_effect="'.esc_attr( $slider_animation ).'">';
				echo '<ul class="slides">';
				
				foreach($custom_posts as $post) : setup_postdata($post);
					$link_to_post = intval( get_post_meta($post->ID,'jot_metabox_link_to_post',true) == ''? false : get_post_meta($post->ID,'jot_metabox_link_to_post',true) );
					$link_to_image = intval( get_post_meta($post->ID,'jot_metabox_link_to_image',true) == ''? false : get_post_meta($post->ID,'jot_metabox_link_to_image',true) );
					$custom_feature_link = esc_url( get_post_meta($post->ID,'jot_custom_feature_link',true) == ''? false : get_post_meta($post->ID,'jot_custom_feature_link',true) );
						if ( has_post_thumbnail() ) {
							
							$jot_feature_pic_count ++;
							
							echo '<li>';
							
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID),'large') ;
								$image_url = $thumb[0];
								$title = the_title_attribute('echo=0');
						 		if( $title == '' ) {
						 			$imagetitle = '';
									$imagealt = 'flexslider image';
								} else {
									$imagetitle = $title;
									$imagealt = $title;
								}
						 		
								//Set up the link
						 		if( $link_to_post == true ) {
						 			echo '<a href="'.get_permalink().'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} elseif ( $link_to_image == true ) {
						 			echo '<a href="'.$image_url.'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} elseif ( $custom_feature_link != false ) {
						 			echo '<a href="'.$custom_feature_link.'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} else {
						 			echo '<img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$title.'" />';
						 		}
								//wp_die($include_post_titles);
								If( $include_post_titles == true ) {
									if( $title != '' ){
										echo '<p class="flex-caption">'.$title.'</p>';
									}
								}
							
							echo '</li>';
							
						}
						
					endforeach;
				
				echo '</ul>';
			echo '</div>';

		echo '</div>';
		
	} else {
		echo '<div class="error" style="text-align: left;">';
			echo __('You have not set up your Feature posts so I can not find any images.','jot');
			echo '<ol>';
				echo '<li style="list-style: decimal;">'.__('Create a specific category such as "feature 1" to use for your feature posts.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Add a new post using the created category and insert the featured image.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Images can be linked to the post, image file, or a custom link.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Repeat for new images.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Select the category from the drop down when you set up the widget','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Make sure the images are exactly the same width and height.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Ideal image width is 840px.','jot').'</li>';
			echo '</ol>';
		echo '</div>';
	}
				
	if ($jot_feature_pic_count == 0){
			echo '<div class="error">';
			echo __('There were no feature images found, did you select the correct category?','jot');
			echo '</div>';
	}
}

/**
 * 
 */
function jot_slider_button_nav( $slider_category, $slider_animation, $slider_pause, $slider_transition , $include_post_titles ){
	global $jot_feature_category, $post;

	$category_ID = get_cat_ID( $slider_category );		
	$args = array('category'=>$category_ID,'numberposts'=>999);
	$custom_posts = get_posts($args);
	$jot_feature_pic_count = 0;

	if ($category_ID !== 0 && $custom_posts){
		
		echo '<div class="flexslider-wrapper">';
		
			// slider
			echo '<div id="flexslider-feature-button" class="flexslider" data-flex_trans="'.esc_attr( $slider_transition ).'" data-flex_pause="'.esc_attr( $slider_pause ).'" data-flex_effect="'.esc_attr( $slider_animation ).'">';
				echo '<ul class="slides">';

				foreach($custom_posts as $post) : setup_postdata($post);
					$link_to_post = intval( get_post_meta($post->ID,'jot_metabox_link_to_post',true) == ''? false : get_post_meta($post->ID,'jot_metabox_link_to_post',true) );
					$link_to_image = intval( get_post_meta($post->ID,'jot_metabox_link_to_image',true) == ''? false : get_post_meta($post->ID,'jot_metabox_link_to_image',true) );
					$custom_feature_link = esc_url( get_post_meta($post->ID,'jot_custom_feature_link',true) == ''? false : get_post_meta($post->ID,'jot_custom_feature_link',true) );
						if ( has_post_thumbnail() ) {
							
							$jot_feature_pic_count ++;
							
							echo '<li>';
							
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID),'large') ;
								$image_url = $thumb[0];
								$title = the_title_attribute('echo=0');
						 		if( $title == '' ) {
						 			$imagetitle = '';
									$imagealt = 'flexslider image';
								} else {
									$imagetitle = $title;
									$imagealt = $title;
								}
						 		
								//Set up the link
						 		if( $link_to_post == true ) {
						 			echo '<a href="'.get_permalink().'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} elseif ( $link_to_image == true ) {
						 			echo '<a href="'.$image_url.'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} elseif ( $custom_feature_link != false ) {
						 			echo '<a href="'.$custom_feature_link.'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} else {
						 			echo '<img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$title.'" />';
						 		}
								
								If( $include_post_titles == true ) {
									if( $title != '' ){
										echo '<p class="flex-caption">'.$title.'</p>';
									}
								}
							
							echo '</li>';
							
						}
						
					endforeach;
				
				echo '</ul>';
			echo '</div>';
	
		echo '</div>';
		
	} else {
		echo '<div class="error" style="text-align: left;">';
			echo __('You have not set up your Feature posts so I can not find any images.','jot');
			echo '<ol>';
				echo '<li style="list-style: decimal;">'.__('Create a specific category such as "feature 1" to use for your feature posts.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Add a new post using the created category and insert the featured image.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Images can be linked to the post, image file, or a custom link.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Repeat for new images.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Select the category from the drop down when you set up the widget','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Make sure the images are exactly the same width and height.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Ideal image width is 840px.','jot').'</li>';
			echo '</ol>';
		echo '</div>';
	}
				
	if ($jot_feature_pic_count == 0){
			echo '<div class="error">';
			echo __('There were no feature images found, did you select the correct category?','jot');
			echo '</div>';
	}
}
/**
 * 
 */
function jot_slider_thumb_nav( $slider_category, $slider_animation, $slider_pause, $slider_transition , $include_post_titles ){
	global $jot_feature_category, $post;

	$category_ID = get_cat_ID( $slider_category );		
	$args = array('category'=>$category_ID,'numberposts'=>999);
	$custom_posts = get_posts($args);
	$jot_feature_pic_count = 0;
	
	if ($category_ID !== 0 && $custom_posts){
		
		echo '<div class="flexslider-wrapper">';
		
			echo '<div id="flexslider-carousel-thumb" class="flexslider jot-widget-thumb">';
				echo '<ul class="slides">';

					foreach($custom_posts as $post) : setup_postdata($post);
					
						if ( has_post_thumbnail() ) {
							
							$jot_feature_pic_count ++;
							
							echo '<li>';
							
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID),'wide_thumbnail') ;
								$image_url = $thumb[0];
													 		
						 		//Set up the link
					 			echo '<img src="'.$image_url.'" title="" alt="flex thumb" />';
							
							echo '</li>';
							
						}
						
					endforeach;
						
				echo '</ul>';
			echo '</div>';
			
			// slider
			echo '<div id="flexslider-feature-thumb" class="flexslider" data-flex_trans="'.esc_attr( $slider_transition ).'" data-flex_pause="'.esc_attr( $slider_pause ).'" data-flex_effect="'.esc_attr( $slider_animation ).'">';
				echo '<ul class="slides">';
				
				$jot_feature_pic_count = 0;
				
				foreach($custom_posts as $post) : setup_postdata($post);
					$link_to_post = intval( get_post_meta($post->ID,'jot_metabox_link_to_post',true) == ''? false : get_post_meta($post->ID,'jot_metabox_link_to_post',true) );
					$link_to_image = intval( get_post_meta($post->ID,'jot_metabox_link_to_image',true) == ''? false : get_post_meta($post->ID,'jot_metabox_link_to_image',true) );
					$custom_feature_link = esc_url( get_post_meta($post->ID,'jot_custom_feature_link',true) == ''? false : get_post_meta($post->ID,'jot_custom_feature_link',true) );
						if ( has_post_thumbnail() ) {
							
							$jot_feature_pic_count ++;
							
							echo '<li>';
							
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID),'large') ;
								$image_url = $thumb[0];
								$title = the_title_attribute('echo=0');
						 		if( $title == '' ) {
						 			$imagetitle = '';
									$imagealt = 'flexslider image';
								} else {
									$imagetitle = $title;
									$imagealt = $title;
								}
						 		
								//Set up the link
						 		if( $link_to_post == true ) {
						 			echo '<a href="'.get_permalink().'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} elseif ( $link_to_image == true ) {
						 			echo '<a href="'.$image_url.'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} elseif ( $custom_feature_link != false ) {
						 			echo '<a href="'.$custom_feature_link.'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} else {
						 			echo '<img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$title.'" />';
						 		}
								
								If( $include_post_titles == true ) {
									if( $title != '' ){
										echo '<p class="flex-caption">'.$title.'</p>';
									}
								}
							
							echo '</li>';
							
						}
						
					endforeach;
				
				echo '</ul>';
			echo '</div>';
		echo '</div>';

	} else {
		echo '<div class="error" style="text-align: left;">';
			echo __('You have not set up your Feature posts so I can not find any images.','jot');
			echo '<ol>';
				echo '<li style="list-style: decimal;">'.__('Create a specific category such as "feature 1" to use for your feature posts.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Add a new post using the created category and insert the featured image.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Images can be linked to the post, image file, or a custom link.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Repeat for new images.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Select the category from the drop down when you set up the widget','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Make sure the images are exactly the same width and height.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Ideal image width is 840px.','jot').'</li>';
			echo '</ol>';
		echo '</div>';
	}
				
	if ($jot_feature_pic_count == 0){
			echo '<div class="error">';
			echo __('There were no feature images found, did you select the correct category?','jot');
			echo '</div>';
	}

}

/**
 * 
 */
function jot_slider_carousel( $slider_category, $slider_animation, $slider_pause, $slider_transition , $include_post_titles ){
	global $jot_feature_category, $post;

	$category_ID = get_cat_ID( $slider_category );		
	$args = array('category'=>$category_ID,'numberposts'=>999);
	$custom_posts = get_posts($args);
	$jot_feature_pic_count = 0;
	
	if ($category_ID !== 0 && $custom_posts){
		
		echo '<div class="flexslider-wrapper">';
		
			echo '<div id="flexslider-feature-carousel" class="flexslider jot-widget-carousel">';
				echo '<ul class="slides">';
				
				foreach($custom_posts as $post) : setup_postdata($post);
					$link_to_post = intval( get_post_meta($post->ID,'jot_metabox_link_to_post',true) == ''? false : get_post_meta($post->ID,'jot_metabox_link_to_post',true) );
					$link_to_image = intval( get_post_meta($post->ID,'jot_metabox_link_to_image',true) == ''? false : get_post_meta($post->ID,'jot_metabox_link_to_image',true) );
					$custom_feature_link = esc_url( get_post_meta($post->ID,'jot_custom_feature_link',true) == ''? false : get_post_meta($post->ID,'jot_custom_feature_link',true) );
						if ( has_post_thumbnail() ) {
							
							$jot_feature_pic_count ++;
							
							echo '<li>';
							
								$thumb = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID),'large') ;
								$image_url = $thumb[0];
								$title = the_title_attribute('echo=0');
						 		if( $title == '' ) {
						 			$imagetitle = '';
									$imagealt = 'flexslider image';
								} else {
									$imagetitle = $title;
									$imagealt = $title;
								}
						 		
								//Set up the link
						 		if( $link_to_post == true ) {
						 			echo '<a href="'.get_permalink().'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} elseif ( $link_to_image == true ) {
						 			echo '<a href="'.$image_url.'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} elseif ( $custom_feature_link != false ) {
						 			echo '<a href="'.$custom_feature_link.'" title="'.the_title_attribute(array('echo' => false)).'"><img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$imagealt.'" /></a>';
						 		} else {
						 			echo '<img src="'.$image_url.'" title="'.$imagetitle.'" alt="'.$title.'" />';
						 		}
								
								If( $include_post_titles == true ) {
									if( $title != '' ){
										echo '<p class="flex-caption">'.$title.'</p>';
									}
								}
							
							echo '</li>';
							
						}
						
					endforeach;
				
				echo '</ul>';
			echo '</div>';
			
		echo '</div>';
		
	} else {
		echo '<div class="error" style="text-align: left;">';
			echo __('You have not set up your Feature posts so I can not find any images.','jot');
			echo '<ol>';
				echo '<li style="list-style: decimal;">'.__('Create a specific category such as "feature 1" to use for your feature posts.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Add a new post using the created category and insert the featured image.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Images can be linked to the post, image file, or a custom link.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Repeat for new images.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Select the category from the drop down when you set up the widget','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Make sure the images are exactly the same width and height.','jot').'</li>';
				echo '<li style="list-style: decimal;">'.__('Tip: Ideal image width is 840px.','jot').'</li>';
			echo '</ol>';
		echo '</div>';
	}
				
	if ($jot_feature_pic_count == 0){
			echo '<div class="error">';
			echo __('There were no feature images found, did you select the correct category?','jot');
			echo '</div>';
	}
}